/*
 *  $Id: splash.c 27936 2025-05-09 09:14:17Z yeti-dn $
 *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include <string.h>
#include <stdlib.h>
#include <glib/gi18n.h>
#include <gtk/gtk.h>

#include "libgwyddion/macros.h"
#include "libgwyddion/utils.h"
#include "libgwyddion/version.h"
#include "libgwyddion/gwycontainer.h"
#include "libgwyapp/sanity.h"

typedef struct {
    gchar c;
    gsize len;
    const guchar *data;
} SplashDigit;

static void splash_map(void);

static gboolean in_splash = FALSE;
static GtkWidget *window = NULL;
static GtkWidget *label = NULL;

/* {{{ Digit images */
static const guchar digit_0_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xef, 0x9f, 0xd1, 0xb8, 0x00, 0x00, 0x02,
  0x49, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xa5, 0x94, 0xcd, 0x4b, 0x15,
  0x51, 0x18, 0xc6, 0x7f, 0x33, 0x5e, 0xaf, 0xe5, 0x48, 0x5f, 0xb4, 0x10,
  0x6e, 0x52, 0x0a, 0xe5, 0x0d, 0xfa, 0x22, 0x0b, 0x34, 0xa8, 0x8d, 0x7f,
  0x41, 0x86, 0xd1, 0x3a, 0x69, 0x99, 0x86, 0xd4, 0xd6, 0x16, 0x41, 0x1f,
  0x9b, 0x5a, 0xb4, 0x0b, 0xaa, 0x65, 0x51, 0x1a, 0x41, 0x1f, 0x90, 0xe1,
  0xa6, 0x56, 0x15, 0x11, 0x2d, 0xbc, 0xd6, 0x6d, 0x51, 0x96, 0x62, 0x8b,
  0x92, 0x34, 0xb5, 0xdb, 0x35, 0xe7, 0x69, 0x71, 0x6e, 0xc7, 0x77, 0x6e,
  0x57, 0x09, 0x7a, 0x07, 0x66, 0xce, 0xfb, 0x3c, 0xcf, 0x3b, 0x67, 0xe6,
  0x9c, 0xf3, 0x3e, 0xf0, 0x9f, 0x51, 0x4d, 0x37, 0x03, 0x8c, 0x22, 0xc4,
  0x28, 0x03, 0x74, 0x53, 0xbd, 0x9c, 0xbc, 0x8d, 0x3c, 0x2a, 0xbb, 0xf2,
  0xb4, 0x2d, 0x25, 0xef, 0x22, 0x46, 0x4d, 0xba, 0xa4, 0x9c, 0x0a, 0x2a,
  0x28, 0xa7, 0x8b, 0x6a, 0x14, 0x22, 0xa6, 0xab, 0x92, 0xbc, 0x93, 0x38,
  0x50, 0xaf, 0x8a, 0xb2, 0xf1, 0x53, 0x27, 0x14, 0x08, 0x71, 0xb8, 0x5c,
  0xde, 0xc0, 0x1c, 0x3a, 0xab, 0x4a, 0x71, 0x46, 0x88, 0x1f, 0x34, 0x24,
  0x0b, 0xee, 0xa1, 0x43, 0x46, 0xd4, 0xaf, 0x9b, 0x26, 0xeb, 0x10, 0xe2,
  0xbe, 0x95, 0xef, 0x46, 0x75, 0x9a, 0xf0, 0x82, 0xd3, 0x42, 0xa8, 0xcf,
  0xe7, 0xe3, 0x8a, 0x84, 0x68, 0x59, 0x2c, 0xb8, 0x8a, 0x7a, 0x3d, 0x3d,
  0xad, 0x5a, 0x51, 0x64, 0x21, 0xd2, 0x94, 0xc7, 0x7a, 0x84, 0xb8, 0xf6,
  0x47, 0x9e, 0x66, 0x26, 0xd0, 0x88, 0x27, 0x6f, 0x0b, 0xf1, 0x88, 0x41,
  0x74, 0xcb, 0x63, 0x39, 0x05, 0x62, 0x86, 0x1a, 0x08, 0x81, 0x56, 0xa2,
  0x2c, 0x59, 0x3f, 0xdd, 0x33, 0x80, 0xc7, 0x0c, 0xc2, 0x73, 0x8f, 0x6d,
  0x25, 0x0b, 0x11, 0xad, 0xae, 0x60, 0x3f, 0xb4, 0x9b, 0x1f, 0x7a, 0x0b,
  0x30, 0xcc, 0x30, 0xbc, 0x31, 0x68, 0x3b, 0xc0, 0x01, 0x48, 0x01, 0xbb,
  0x60, 0xaf, 0xa1, 0x3e, 0x02, 0x4c, 0x10, 0xc3, 0x27, 0x83, 0xb6, 0x00,
  0xec, 0x74, 0x05, 0x8d, 0xd0, 0x6c, 0xa8, 0xaf, 0x00, 0x9f, 0x59, 0x80,
  0x2f, 0x06, 0x6d, 0xc6, 0x29, 0x53, 0xc0, 0x06, 0xc8, 0x18, 0x6a, 0x1a,
  0xe0, 0x1b, 0x82, 0xef, 0x06, 0xcd, 0xe0, 0x94, 0x00, 0x45, 0x34, 0x67,
  0xb6, 0xa9, 0x46, 0x08, 0x00, 0xa5, 0x0d, 0x3a, 0x2b, 0xc4, 0x3c, 0x04,
  0x80, 0x20, 0x26, 0xf0, 0xef, 0xaa, 0x22, 0x2e, 0xe1, 0x21, 0x0b, 0x1e,
  0x8d, 0xa9, 0x02, 0x08, 0x42, 0x97, 0xca, 0x4c, 0x2e, 0x53, 0xfa, 0x37,
  0x1a, 0x02, 0xf3, 0x50, 0x30, 0x54, 0xca, 0x3d, 0x02, 0x12, 0xbd, 0x53,
  0x70, 0x1f, 0x4f, 0xe8, 0x96, 0x65, 0xd2, 0x50, 0x2b, 0x00, 0x56, 0x52,
  0x5b, 0x1a, 0xd9, 0xb5, 0x9b, 0x74, 0x05, 0x63, 0xc9, 0x15, 0x5f, 0x05,
  0xb0, 0x86, 0x75, 0xb0, 0xd6, 0xa0, 0x63, 0xa5, 0x5b, 0x08, 0xbc, 0x87,
  0xbc, 0xa1, 0xd6, 0x03, 0xd4, 0x53, 0x5f, 0x1a, 0xd9, 0xfd, 0xff, 0xe0,
  0x0a, 0x5e, 0xc1, 0x8b, 0x44, 0x2f, 0x01, 0x19, 0x32, 0xb0, 0xc9, 0xa0,
  0x2f, 0x01, 0x5e, 0xbb, 0x82, 0xa7, 0x30, 0x54, 0xbe, 0xa7, 0xdb, 0xd8,
  0x0e, 0x5b, 0x0c, 0x3a, 0x84, 0x53, 0x3a, 0x6b, 0x99, 0x0a, 0x94, 0x33,
  0xdd, 0x86, 0x18, 0xe2, 0x09, 0x7a, 0xe0, 0xb1, 0x11, 0x7f, 0xbc, 0x5d,
  0x5c, 0x41, 0x3d, 0xa6, 0x81, 0x22, 0xf1, 0x8b, 0x78, 0xb5, 0x0a, 0x1e,
  0xeb, 0x15, 0xe2, 0xfa, 0xe2, 0x7c, 0x3b, 0x50, 0xa4, 0x71, 0x4f, 0xf7,
  0x09, 0xa1, 0x0b, 0x3e, 0x9f, 0x50, 0x9d, 0x10, 0x7b, 0x6c, 0x57, 0xdf,
  0x45, 0x07, 0xcd, 0xc9, 0xb9, 0xa1, 0x3b, 0x26, 0xeb, 0x14, 0xe2, 0x61,
  0xd2, 0x35, 0x32, 0xcc, 0xa2, 0x73, 0x15, 0x6d, 0xe6, 0xbc, 0xb3, 0x99,
  0x8d, 0xe5, 0xce, 0xd4, 0x41, 0x1c, 0xe8, 0x94, 0xe6, 0x13, 0xe2, 0xa2,
  0x4e, 0x3a, 0x23, 0x3b, 0x52, 0xc9, 0xfb, 0x8e, 0x12, 0xa3, 0xcd, 0xba,
  0xac, 0xbc, 0x8a, 0x25, 0xab, 0x6c, 0x72, 0x56, 0x79, 0x6c, 0x29, 0x77,
  0x6d, 0xe5, 0x5d, 0x05, 0x33, 0xde, 0xb7, 0x9c, 0x7f, 0xa7, 0x39, 0x4e,
  0xbf, 0xb1, 0xfb, 0x9e, 0xe5, 0xed, 0xfe, 0x1f, 0xe2, 0x37, 0xff, 0x7b,
  0xeb, 0xa3, 0x89, 0x7b, 0xb2, 0xef, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
  0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_1_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xef, 0x9f, 0xd1, 0xb8, 0x00, 0x00, 0x00,
  0xeb, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xed, 0x94, 0xbf, 0x0e, 0xc1,
  0x50, 0x14, 0xc6, 0x7f, 0x6d, 0x24, 0xa6, 0xce, 0x4c, 0x36, 0x89, 0x44,
  0x24, 0x06, 0x2c, 0x57, 0x44, 0xe8, 0x68, 0x90, 0x78, 0x02, 0x8b, 0xd7,
  0xf0, 0x0c, 0x9e, 0x81, 0xc1, 0xc6, 0x62, 0x31, 0x09, 0xab, 0x84, 0x87,
  0x60, 0x36, 0x58, 0x44, 0x22, 0xc7, 0xa0, 0x2d, 0xbd, 0xad, 0xb6, 0x06,
  0x26, 0xdf, 0x59, 0x6e, 0x4e, 0xbe, 0xef, 0x7c, 0xe7, 0xfe, 0x39, 0x17,
  0xa2, 0x60, 0x50, 0x64, 0xa0, 0xa7, 0xc2, 0x60, 0xd2, 0xa6, 0x82, 0xa2,
  0x81, 0xa5, 0x73, 0x52, 0x3e, 0xa2, 0x85, 0x4d, 0x93, 0x1a, 0x35, 0xcc,
  0x77, 0xa6, 0x29, 0xc0, 0xa0, 0x80, 0x42, 0xa1, 0xc8, 0xbb, 0xc9, 0x92,
  0x93, 0xc8, 0x85, 0x8a, 0xa6, 0xc8, 0x23, 0x2c, 0xb1, 0x65, 0x28, 0x4b,
  0x39, 0x8b, 0x0b, 0x04, 0x09, 0x3a, 0xa4, 0xa1, 0x45, 0x17, 0x45, 0xf9,
  0x7d, 0x27, 0x3e, 0xcc, 0x90, 0xb9, 0x84, 0x23, 0xe8, 0xa0, 0x95, 0xbc,
  0xb0, 0x8a, 0xa9, 0xee, 0x9c, 0xd2, 0x89, 0x05, 0x1b, 0x36, 0x6c, 0xb9,
  0xea, 0x25, 0xc3, 0x05, 0x7d, 0x92, 0xc2, 0x6d, 0xe9, 0xc6, 0x9a, 0x11,
  0x76, 0x32, 0x51, 0x8f, 0xba, 0x77, 0x81, 0x42, 0xcc, 0xa6, 0xf5, 0xa7,
  0x21, 0xf8, 0x18, 0x46, 0x80, 0x63, 0xf2, 0x21, 0xfe, 0x82, 0xbf, 0x20,
  0x62, 0x1e, 0x2a, 0x64, 0x23, 0x39, 0x1d, 0x6f, 0x75, 0x60, 0xef, 0xcc,
  0xf4, 0x6b, 0x04, 0x9e, 0xf7, 0x33, 0xc6, 0xde, 0xc4, 0x55, 0xc9, 0xc4,
  0x14, 0x3f, 0xb2, 0x4b, 0xf2, 0x6b, 0x3c, 0x31, 0x71, 0x1c, 0x7e, 0x73,
  0x4a, 0x40, 0xf7, 0x7b, 0x0e, 0x1f, 0xe3, 0x0e, 0x71, 0xf1, 0x9a, 0xf3,
  0x12, 0xb7, 0xa5, 0x71, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44,
  0xae, 0x42, 0x60, 0x82
};
static const guchar digit_2_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xef, 0x9f, 0xd1, 0xb8, 0x00, 0x00, 0x01,
  0xf5, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xb5, 0x94, 0x4f, 0x48, 0x15,
  0x51, 0x14, 0xc6, 0x7f, 0xf3, 0x66, 0xc6, 0xf7, 0x06, 0xdf, 0x26, 0xa8,
  0x08, 0x74, 0xa3, 0x54, 0x24, 0x11, 0x11, 0x68, 0x8b, 0x20, 0x02, 0x21,
  0xa2, 0xc0, 0x8d, 0xad, 0x2c, 0x28, 0xa2, 0x48, 0x5a, 0xb4, 0x09, 0xc2,
  0x4d, 0x9b, 0x22, 0xc4, 0x08, 0x97, 0x8f, 0x16, 0x22, 0x46, 0x11, 0x26,
  0xb4, 0x51, 0x12, 0x5c, 0x88, 0x98, 0x8b, 0x20, 0x2c, 0x78, 0xed, 0x42,
  0x68, 0x21, 0x58, 0xd0, 0x1f, 0x2a, 0x1b, 0x23, 0x33, 0x7d, 0x5f, 0x8b,
  0x99, 0x77, 0xbd, 0xd9, 0x1d, 0xe3, 0x2d, 0xfc, 0xee, 0x62, 0xee, 0xc0,
  0xef, 0x3b, 0xe7, 0xdc, 0x7b, 0xee, 0xbd, 0x50, 0xa3, 0x3c, 0x6b, 0x1e,
  0x72, 0x8a, 0x76, 0xf6, 0xd3, 0x44, 0x33, 0x00, 0x15, 0x5e, 0x51, 0x66,
  0x8c, 0x71, 0xb4, 0xd1, 0x16, 0x71, 0x86, 0x49, 0x2a, 0xc8, 0x39, 0xbe,
  0x70, 0x75, 0x3d, 0xb0, 0x07, 0x44, 0xc4, 0xf8, 0xe0, 0xd3, 0x4a, 0x3b,
  0x87, 0x69, 0xa1, 0x81, 0x7a, 0x7e, 0xf3, 0x99, 0x37, 0xcc, 0x30, 0xcc,
  0x1c, 0xc0, 0x34, 0x1d, 0x2c, 0x55, 0x4d, 0x45, 0x14, 0xaa, 0xa4, 0x0f,
  0x72, 0xeb, 0xb1, 0x76, 0x0a, 0x51, 0x26, 0x6f, 0x19, 0x8a, 0xda, 0x4c,
  0xf3, 0x6a, 0x12, 0xe2, 0x5e, 0xb5, 0xa4, 0x22, 0x71, 0x91, 0x38, 0x75,
  0xc7, 0xbc, 0xe6, 0x3d, 0x11, 0x87, 0x68, 0xb4, 0x16, 0x59, 0xa6, 0x8d,
  0xd5, 0x0a, 0xcd, 0xcc, 0x5b, 0x19, 0xbe, 0xa9, 0xa4, 0xa3, 0x0a, 0xd2,
  0xa5, 0xe6, 0x74, 0x41, 0xab, 0x56, 0x96, 0x73, 0x42, 0xf4, 0x99, 0x92,
  0x0a, 0xba, 0xa2, 0xfa, 0x04, 0x5d, 0xe3, 0x19, 0x0f, 0x19, 0xe1, 0x3b,
  0xea, 0xb5, 0x0c, 0x13, 0x42, 0xbc, 0x30, 0x86, 0x74, 0x4c, 0xd3, 0x45,
  0x21, 0xad, 0xe2, 0x18, 0x6a, 0xb1, 0x0c, 0x1f, 0x85, 0xf8, 0xb1, 0x6e,
  0x58, 0x66, 0x80, 0xbd, 0x1b, 0x5a, 0xaa, 0xbc, 0x65, 0x58, 0x4b, 0x42,
  0xa6, 0x6d, 0xbb, 0xcb, 0x8e, 0x7f, 0xce, 0x40, 0x88, 0x22, 0xcb, 0xb0,
  0x24, 0x44, 0x65, 0xb3, 0x43, 0x73, 0x04, 0x1d, 0xb0, 0x0c, 0xb3, 0x42,
  0xbc, 0x85, 0x5c, 0xa6, 0xe1, 0x26, 0x74, 0x5a, 0xbf, 0xa3, 0x00, 0x53,
  0xd9, 0xf1, 0x6f, 0xa3, 0x5d, 0xfa, 0x6a, 0xe2, 0x2f, 0x6a, 0xbb, 0x10,
  0x27, 0xb2, 0xf0, 0x6e, 0x54, 0xa7, 0x29, 0xab, 0xa0, 0x8b, 0x42, 0x3c,
  0xcf, 0xc2, 0x7b, 0x90, 0xaf, 0x47, 0x16, 0x5e, 0x92, 0x27, 0x7e, 0xb1,
  0xdb, 0x8d, 0xdf, 0x40, 0xbe, 0x1e, 0x58, 0xf8, 0xa0, 0x7c, 0x21, 0xce,
  0xbb, 0xf1, 0x3e, 0x14, 0x68, 0xd8, 0xc2, 0x7b, 0xe5, 0x09, 0xd1, 0xed,
  0xc6, 0xfb, 0x51, 0x9d, 0x9e, 0x18, 0x78, 0x59, 0x67, 0x93, 0xdd, 0xbf,
  0xe4, 0xbe, 0xac, 0x43, 0x28, 0xaf, 0x51, 0x83, 0xbf, 0x53, 0x9b, 0x10,
  0x31, 0xc7, 0xdd, 0xd1, 0xef, 0xa0, 0x82, 0x9e, 0x1a, 0xbc, 0xac, 0x86,
  0xa4, 0x55, 0x7b, 0xdc, 0xf8, 0x69, 0x14, 0x6a, 0xcc, 0xc2, 0xb7, 0x09,
  0x31, 0x49, 0xe4, 0xc6, 0x0f, 0xb2, 0xe2, 0x69, 0xc0, 0xe0, 0x9f, 0xd4,
  0x28, 0xc4, 0xfd, 0xbf, 0xde, 0x94, 0x54, 0x01, 0x10, 0x30, 0x42, 0x78,
  0xd9, 0x5a, 0xd9, 0x35, 0x16, 0x60, 0x85, 0x39, 0x7a, 0x1c, 0xbb, 0x08,
  0xdc, 0x42, 0xfb, 0xf4, 0xd3, 0xc4, 0x5f, 0x48, 0xf6, 0xdd, 0x3d, 0x08,
  0x80, 0x93, 0xd0, 0x6f, 0xee, 0x0d, 0x2c, 0x72, 0x3d, 0xa3, 0x45, 0x55,
  0xcd, 0xa2, 0x97, 0xfa, 0xbf, 0x92, 0x0c, 0xb9, 0x5a, 0xdf, 0xd6, 0xad,
  0x37, 0x04, 0xc9, 0xa7, 0x75, 0xeb, 0x32, 0xd4, 0xac, 0x3f, 0x18, 0x25,
  0xe5, 0xc7, 0x9c, 0x6c, 0x67, 0x4b, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
  0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_3_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x17, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0x1e, 0x94, 0x8a, 0x35, 0x00, 0x00, 0x02,
  0x62, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0x9d, 0x94, 0x4d, 0x48, 0x94,
  0x41, 0x18, 0xc7, 0x7f, 0xbb, 0x2a, 0x26, 0x66, 0x69, 0x4a, 0x1f, 0x9a,
  0xf8, 0x41, 0x7a, 0x28, 0x13, 0x2a, 0xb7, 0x2e, 0x65, 0x11, 0x0b, 0x09,
  0x21, 0xd6, 0x25, 0x04, 0x23, 0x2a, 0x22, 0x04, 0x85, 0xea, 0x56, 0x44,
  0x11, 0x5d, 0x3c, 0x44, 0x50, 0x89, 0xe0, 0x2d, 0x68, 0xc3, 0x0e, 0x1d,
  0x42, 0x94, 0xa2, 0x53, 0x07, 0x31, 0x72, 0x35, 0x0b, 0x8c, 0xec, 0x43,
  0xd8, 0xa2, 0xd8, 0x24, 0xd2, 0x36, 0xc9, 0x74, 0xd7, 0xb5, 0x7f, 0x87,
  0xf7, 0x75, 0x9c, 0xdd, 0x5c, 0xa1, 0x9e, 0xf7, 0xf0, 0x0e, 0x33, 0xff,
  0xe7, 0x37, 0xf3, 0x7c, 0xcc, 0xc0, 0x3f, 0x99, 0xc7, 0xfd, 0x67, 0xd3,
  0x44, 0x05, 0xe5, 0xf8, 0xd8, 0xe8, 0xce, 0x85, 0x09, 0xd3, 0x4b, 0x0f,
  0xc3, 0xc9, 0x2e, 0x7b, 0xe9, 0x62, 0x06, 0xa5, 0xf8, 0x06, 0x29, 0x4b,
  0x94, 0x87, 0x90, 0x57, 0x35, 0xba, 0xa0, 0x07, 0x7a, 0xad, 0xef, 0x8a,
  0x6b, 0x5e, 0x11, 0xbd, 0x52, 0x97, 0x8e, 0x6b, 0xa5, 0x10, 0x71, 0x4e,
  0x27, 0xc9, 0x07, 0xb4, 0xb4, 0x4d, 0xaa, 0x45, 0x1e, 0x21, 0x9a, 0x12,
  0xe4, 0x1f, 0x94, 0xda, 0x6e, 0x08, 0xf1, 0x93, 0x35, 0x00, 0xe9, 0x8b,
  0x5e, 0x73, 0x3c, 0x67, 0x94, 0x09, 0xb2, 0xa8, 0xa2, 0xd6, 0xe4, 0x00,
  0xce, 0xf0, 0x98, 0x47, 0xd9, 0x9c, 0xe5, 0xb2, 0xa1, 0xf7, 0xea, 0x94,
  0x56, 0x5b, 0x01, 0x56, 0x2b, 0x6c, 0xf1, 0x1f, 0x3a, 0x21, 0xbb, 0x89,
  0x0c, 0x51, 0xea, 0x41, 0x00, 0x23, 0xf4, 0x31, 0x45, 0x06, 0xf5, 0x54,
  0x36, 0x72, 0xcf, 0xf0, 0x27, 0xc9, 0x87, 0x18, 0x99, 0x86, 0x4e, 0x94,
  0x8b, 0xac, 0x32, 0xeb, 0x6b, 0x51, 0xbe, 0x45, 0x9f, 0x77, 0xf6, 0x74,
  0xed, 0x1d, 0x9d, 0x14, 0x25, 0xd5, 0x42, 0x99, 0x96, 0x3c, 0x2c, 0x44,
  0x74, 0x61, 0x69, 0xfd, 0x5f, 0xb5, 0xde, 0x89, 0x2a, 0x2c, 0xf9, 0x1d,
  0x21, 0xfa, 0x17, 0x32, 0x33, 0x0e, 0x6c, 0x66, 0x03, 0x1e, 0xbc, 0xe4,
  0xb2, 0x89, 0x2a, 0x8e, 0xc0, 0x51, 0xe3, 0x1b, 0xa5, 0x0d, 0x20, 0x60,
  0xf3, 0x02, 0x76, 0xe1, 0xd3, 0xd5, 0xac, 0x98, 0x4b, 0x8e, 0xea, 0xb0,
  0x10, 0x9f, 0xc9, 0x4e, 0xca, 0x7b, 0x35, 0x25, 0xe4, 0x50, 0x48, 0x15,
  0x7e, 0x13, 0xca, 0x00, 0xcd, 0xbc, 0x84, 0x08, 0xfb, 0x99, 0x4e, 0xa2,
  0xdf, 0x4d, 0xa8, 0x65, 0x4c, 0xdd, 0xaa, 0x73, 0x1a, 0x20, 0xc6, 0xb6,
  0x05, 0x99, 0x37, 0x55, 0x67, 0xcf, 0x02, 0xc5, 0xe4, 0x01, 0x64, 0x70,
  0x85, 0x15, 0x89, 0xab, 0x01, 0xd4, 0xae, 0x2f, 0x8a, 0x28, 0x9e, 0xb0,
  0xc7, 0x8c, 0x6e, 0x39, 0xd5, 0x1e, 0x4e, 0x74, 0x08, 0x2c, 0x86, 0x59,
  0xaa, 0x46, 0x75, 0x5b, 0x2e, 0x63, 0x2a, 0x13, 0xb2, 0x8a, 0x0c, 0xdc,
  0xe4, 0x93, 0xfb, 0xcd, 0x3a, 0x6e, 0x0d, 0x26, 0x37, 0xd2, 0xa8, 0xb2,
  0x84, 0xd8, 0xb1, 0xf4, 0xb1, 0xcb, 0x39, 0xc6, 0x38, 0xba, 0x66, 0xed,
  0x70, 0x4e, 0x88, 0xce, 0xd4, 0x77, 0x78, 0x1f, 0xda, 0x6e, 0xc9, 0x83,
  0x42, 0x84, 0x96, 0xbb, 0xf2, 0xca, 0xb1, 0xe4, 0xd3, 0x6e, 0x93, 0x79,
  0xd9, 0x45, 0x07, 0xb5, 0x4b, 0x25, 0x34, 0x6e, 0x8d, 0x33, 0xcd, 0xc8,
  0x8f, 0x10, 0x93, 0x5c, 0x62, 0x37, 0x69, 0x66, 0xf6, 0x00, 0xda, 0x6a,
  0xd1, 0x3f, 0x0a, 0x31, 0xe1, 0x36, 0x81, 0x07, 0xe5, 0x71, 0x15, 0x98,
  0xe7, 0x05, 0x7d, 0x44, 0x29, 0xa1, 0x01, 0x4e, 0x5a, 0xf4, 0x27, 0x00,
  0x43, 0x2e, 0xdd, 0xaf, 0xa0, 0xce, 0x6b, 0x8b, 0x53, 0x72, 0x21, 0x94,
  0xa6, 0x56, 0xfd, 0xb6, 0xe8, 0x35, 0x42, 0xb4, 0x9a, 0x16, 0xf3, 0xe1,
  0xa3, 0x8d, 0xaf, 0x04, 0x09, 0x31, 0xc7, 0x3a, 0x6a, 0x29, 0xb6, 0xd8,
  0xd7, 0x19, 0x82, 0x08, 0xb7, 0x0d, 0x7d, 0x39, 0x6b, 0x97, 0x57, 0x88,
  0x7a, 0x13, 0x6a, 0x6a, 0xf9, 0x88, 0x0e, 0x3a, 0xc7, 0x6b, 0x71, 0xc4,
  0xe9, 0x00, 0xfd, 0xd4, 0xe1, 0xa3, 0x9a, 0x0a, 0x8a, 0xc8, 0x25, 0x83,
  0x18, 0xdf, 0x78, 0xcf, 0x33, 0x7a, 0x78, 0x8a, 0x60, 0x9a, 0x13, 0xdc,
  0x5f, 0xbc, 0x15, 0x6f, 0x53, 0x3e, 0xa7, 0xe2, 0x17, 0x1d, 0x14, 0x26,
  0x3f, 0xd8, 0x59, 0x1c, 0x62, 0x0f, 0x45, 0x14, 0x50, 0x49, 0x01, 0x00,
  0x3f, 0x78, 0xc3, 0x20, 0x41, 0xba, 0x99, 0xe2, 0xff, 0xed, 0x0f, 0xb0,
  0x94, 0x25, 0x75, 0x81, 0x02, 0x16, 0x02, 0x00, 0x00, 0x00, 0x00, 0x49,
  0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_4_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xeb, 0x6a, 0x01, 0x85, 0x00, 0x00, 0x01,
  0x19, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xd5, 0xd4, 0x4d, 0x2b, 0x44,
  0x61, 0x18, 0x87, 0xf1, 0xeb, 0x19, 0x76, 0x83, 0x61, 0x6f, 0x61, 0x61,
  0x23, 0x91, 0x44, 0xd9, 0xc8, 0xca, 0x17, 0xb0, 0x9f, 0xa4, 0x44, 0x52,
  0xbe, 0x80, 0x8d, 0x6f, 0x61, 0x4a, 0x36, 0xa4, 0x59, 0x90, 0x7c, 0x04,
  0x6b, 0x6b, 0x11, 0x79, 0xd9, 0x5a, 0xd9, 0x30, 0x0d, 0x9a, 0xba, 0x6c,
  0x9e, 0xc2, 0x8c, 0x39, 0x2f, 0x68, 0xca, 0x7d, 0x36, 0xa7, 0xfe, 0xf7,
  0xaf, 0xa7, 0xee, 0xe7, 0xdc, 0x07, 0xfe, 0xb8, 0x76, 0xb0, 0xe9, 0x49,
  0xad, 0x72, 0x0b, 0x49, 0x45, 0x23, 0x3c, 0xe3, 0xae, 0x1f, 0x95, 0x8e,
  0x8a, 0x9c, 0xe3, 0xa2, 0xe6, 0x42, 0xfb, 0x38, 0x6a, 0x2d, 0x17, 0x5a,
  0xc2, 0xa2, 0x17, 0x9a, 0x03, 0x8d, 0x51, 0x0b, 0xee, 0x69, 0x0e, 0xd4,
  0xc3, 0x25, 0x2e, 0xc7, 0xc6, 0xb3, 0x8c, 0xa8, 0x8a, 0xe3, 0xd6, 0x55,
  0x7d, 0x72, 0x38, 0x13, 0x5a, 0xc1, 0x5e, 0xaf, 0x62, 0x5b, 0x59, 0x32,
  0xa0, 0x09, 0xea, 0xc1, 0x6a, 0x6c, 0x3a, 0x30, 0x64, 0x40, 0x7d, 0x5c,
  0xe3, 0x5a, 0x6c, 0xb9, 0xb3, 0x24, 0x19, 0xd0, 0x21, 0x4e, 0xfa, 0xaa,
  0x6a, 0xc3, 0x99, 0xf8, 0xe1, 0x24, 0xa3, 0x75, 0x2c, 0x79, 0x13, 0x1b,
  0x36, 0x45, 0x1e, 0xd2, 0xd0, 0x14, 0x2f, 0xc1, 0xa3, 0x18, 0x9f, 0xda,
  0x25, 0x0d, 0x66, 0x93, 0x51, 0x3f, 0xb7, 0xb8, 0x11, 0xc3, 0x47, 0x07,
  0x45, 0xb6, 0x20, 0x09, 0x05, 0x8e, 0x71, 0xda, 0xb7, 0x18, 0x2e, 0x7c,
  0x59, 0x86, 0x26, 0x24, 0xb2, 0x0d, 0x30, 0x8f, 0x03, 0xde, 0xc7, 0xa8,
  0xd2, 0xb4, 0x41, 0xdf, 0xa3, 0x02, 0x45, 0x98, 0x63, 0x28, 0x1e, 0xbb,
  0xda, 0x76, 0xeb, 0x44, 0x2a, 0xf1, 0xbd, 0xf0, 0x93, 0xff, 0x40, 0xe7,
  0x50, 0x37, 0xc0, 0x09, 0xa1, 0x4d, 0xec, 0xa7, 0x21, 0xff, 0xf2, 0xa4,
  0x90, 0x90, 0xd9, 0x72, 0x52, 0xf8, 0x17, 0xd3, 0xeb, 0xf0, 0x3d, 0xe5,
  0x1d, 0x6e, 0x81, 0x4e, 0xd5, 0x3b, 0xea, 0x9f, 0xa8, 0x7d, 0xcf, 0x59,
  0x03, 0x97, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
  0x60, 0x82
};
static const guchar digit_5_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x16, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xf1, 0x56, 0xe1, 0x0b, 0x00, 0x00, 0x01,
  0xd1, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xb5, 0x94, 0xc1, 0x4b, 0x54,
  0x51, 0x14, 0xc6, 0x7f, 0x4e, 0x19, 0xce, 0xcc, 0xc6, 0x4a, 0xb2, 0x70,
  0xa3, 0x68, 0x8b, 0x16, 0x0e, 0x08, 0xd2, 0x42, 0x70, 0x53, 0x03, 0x06,
  0xce, 0x26, 0x30, 0x08, 0x41, 0x08, 0x6c, 0x31, 0x0b, 0x77, 0xfe, 0x09,
  0xb6, 0x98, 0x4d, 0xeb, 0x20, 0x21, 0xac, 0x04, 0x15, 0x05, 0x15, 0x12,
  0xa4, 0xd5, 0x58, 0x38, 0x43, 0x69, 0x0b, 0x09, 0x1c, 0x24, 0x24, 0x25,
  0x67, 0x21, 0xf3, 0x10, 0x26, 0xb4, 0x34, 0x1c, 0xbf, 0x16, 0x97, 0x79,
  0x73, 0x47, 0xdf, 0x83, 0x37, 0x41, 0xe7, 0xad, 0xce, 0xe3, 0x77, 0xbe,
  0x77, 0xce, 0xfd, 0xce, 0x7d, 0x50, 0x63, 0x24, 0x51, 0x80, 0x67, 0x04,
  0x42, 0xb5, 0xa8, 0x86, 0x82, 0x88, 0x8f, 0x54, 0xc3, 0x35, 0x29, 0xff,
  0x07, 0xf8, 0x72, 0x75, 0x9a, 0xe3, 0x8d, 0x07, 0x94, 0xf5, 0x86, 0x37,
  0x48, 0x05, 0x57, 0x3e, 0x02, 0xf8, 0xcc, 0xbc, 0x07, 0x99, 0xb9, 0x00,
  0x1f, 0x9a, 0xaf, 0xa6, 0x02, 0x29, 0x1f, 0x02, 0xf4, 0x73, 0xca, 0x36,
  0x19, 0x36, 0x82, 0xc0, 0x1d, 0x8c, 0x02, 0xf0, 0x9d, 0x97, 0xbc, 0xa0,
  0x78, 0x61, 0x37, 0x92, 0x32, 0xb1, 0xad, 0x65, 0x4d, 0xea, 0x99, 0x1e,
  0xa9, 0xc9, 0x98, 0x77, 0x40, 0xd2, 0x17, 0xae, 0x44, 0x49, 0xef, 0xd4,
  0x63, 0x0a, 0xa6, 0xca, 0x6e, 0x84, 0xfc, 0xdd, 0xea, 0x67, 0x95, 0x57,
  0x44, 0xe1, 0x31, 0x6f, 0xcd, 0xbb, 0x4b, 0x40, 0x37, 0x89, 0x9b, 0x88,
  0x8f, 0x7c, 0xe5, 0x07, 0x61, 0x1a, 0xad, 0x92, 0x2e, 0xee, 0x31, 0xc3,
  0x9f, 0x4e, 0x0a, 0xac, 0x79, 0xae, 0x5c, 0x4c, 0xd3, 0x55, 0x0d, 0x4d,
  0x0a, 0xe1, 0x10, 0x2d, 0x2b, 0xf7, 0xf1, 0x85, 0x34, 0x69, 0xb2, 0xec,
  0xd2, 0xbc, 0x1f, 0x9d, 0xa3, 0xc8, 0x03, 0x57, 0x3d, 0xc6, 0x32, 0xf9,
  0x08, 0x7b, 0xac, 0x03, 0x84, 0xcf, 0xb5, 0x3b, 0xc0, 0x31, 0x5a, 0xb2,
  0xb4, 0xc7, 0x85, 0x58, 0xf0, 0x9b, 0xee, 0x29, 0x4a, 0x58, 0xf0, 0x96,
  0x10, 0x79, 0x3f, 0x38, 0x8c, 0x9a, 0x2d, 0xf8, 0xc4, 0x4c, 0x43, 0x9d,
  0x0f, 0xae, 0x2b, 0x9c, 0xb8, 0x49, 0xc9, 0x18, 0x5d, 0x17, 0x02, 0x16,
  0x79, 0x78, 0xee, 0xbc, 0x5b, 0xe0, 0x86, 0x95, 0xee, 0x03, 0x65, 0xdb,
  0x0b, 0x88, 0x3c, 0xc3, 0xd6, 0x9e, 0x8c, 0xa3, 0x21, 0xab, 0x8d, 0x05,
  0x21, 0x3e, 0x54, 0x60, 0x21, 0x4e, 0xc9, 0xf2, 0x9c, 0x14, 0x19, 0x14,
  0xd1, 0xa6, 0x05, 0x0f, 0x0a, 0x31, 0xe6, 0xc2, 0x13, 0x4a, 0xa8, 0xde,
  0xb5, 0xe5, 0x96, 0xde, 0x5b, 0x68, 0x4e, 0xf5, 0xe2, 0x8c, 0x56, 0x33,
  0x60, 0x81, 0x26, 0x87, 0xeb, 0xfc, 0x64, 0x95, 0x6f, 0x88, 0x76, 0xe2,
  0x34, 0xb8, 0x1d, 0x1d, 0xd3, 0xcb, 0x3a, 0xbc, 0xe6, 0x89, 0xab, 0xec,
  0xc8, 0x3b, 0x8a, 0x8a, 0x0b, 0xb1, 0x53, 0xa9, 0xf6, 0x85, 0x17, 0xd5,
  0x26, 0xc4, 0x2f, 0x3a, 0xab, 0x6e, 0xca, 0x00, 0x77, 0x89, 0x71, 0x87,
  0x56, 0xae, 0x52, 0xc2, 0x61, 0x8b, 0x15, 0xa6, 0xc9, 0x99, 0x0b, 0x1f,
  0xc7, 0xa9, 0x1c, 0xe3, 0x8a, 0xef, 0x4f, 0xee, 0x37, 0xa3, 0xb6, 0x03,
  0xc6, 0xc1, 0x08, 0xf7, 0xb9, 0x4d, 0x37, 0x1d, 0xb4, 0x73, 0x0d, 0x38,
  0x60, 0x97, 0x4f, 0xcc, 0x92, 0xe6, 0x8c, 0x7f, 0x8d, 0xbf, 0x6e, 0x65,
  0x71, 0xf9, 0xa3, 0xc8, 0x3c, 0x61, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
  0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_6_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xeb, 0x6a, 0x01, 0x85, 0x00, 0x00, 0x02,
  0xa6, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xa5, 0x94, 0x4b, 0x48, 0x94,
  0x51, 0x18, 0x86, 0x9f, 0xf1, 0x32, 0x2a, 0xde, 0x0b, 0xa9, 0x46, 0x85,
  0x8a, 0xa8, 0x85, 0x54, 0x6a, 0x65, 0x25, 0x2d, 0x14, 0x5d, 0x44, 0x60,
  0x82, 0x10, 0x11, 0x51, 0xd0, 0xa2, 0xdc, 0x68, 0xb4, 0x28, 0x82, 0xa8,
  0x45, 0x9b, 0xa4, 0x4d, 0x44, 0x04, 0x5d, 0xa0, 0xab, 0x41, 0x41, 0x58,
  0x2e, 0x4c, 0xb0, 0xa8, 0xb4, 0x40, 0x53, 0x69, 0x91, 0x97, 0x85, 0x0d,
  0xa5, 0x4d, 0x2e, 0x64, 0xbc, 0x96, 0x9a, 0x3a, 0x39, 0xbe, 0x2d, 0x7e,
  0xe7, 0xf7, 0x38, 0xfe, 0x15, 0xd4, 0xf7, 0xaf, 0xce, 0x79, 0xcf, 0x73,
  0xbe, 0xff, 0xbc, 0xe7, 0x3b, 0x1f, 0xfc, 0x43, 0xb8, 0x1c, 0x67, 0x77,
  0x50, 0x42, 0x0e, 0x9b, 0xf1, 0x00, 0x30, 0x88, 0x97, 0x1e, 0x9a, 0x69,
  0xa3, 0x13, 0x39, 0x2d, 0x8f, 0xa0, 0x92, 0x5e, 0xf4, 0x9b, 0x2f, 0x40,
  0x29, 0x40, 0xd4, 0x22, 0x64, 0x1d, 0x0d, 0xac, 0x05, 0x0f, 0xfb, 0x28,
  0x24, 0x0b, 0x0f, 0x71, 0x4c, 0xe1, 0xe7, 0x13, 0x9d, 0xb4, 0xf3, 0x82,
  0xc1, 0x68, 0x32, 0xc3, 0xb3, 0xe4, 0xf1, 0x1d, 0x79, 0x74, 0x57, 0x41,
  0x39, 0x45, 0x85, 0x10, 0x15, 0x8b, 0x33, 0xe5, 0xf2, 0x16, 0x77, 0x09,
  0xd5, 0x24, 0xff, 0xd5, 0x88, 0x10, 0x94, 0x42, 0x3d, 0xee, 0x83, 0x54,
  0x1b, 0xce, 0x78, 0x69, 0x66, 0x88, 0x44, 0x36, 0xb0, 0x95, 0x78, 0x47,
  0xe8, 0x2a, 0x2b, 0x76, 0x72, 0xc7, 0x46, 0xbc, 0x94, 0xd3, 0x68, 0x5b,
  0xe5, 0x26, 0x9f, 0x52, 0xfc, 0x61, 0xf9, 0x36, 0x31, 0x17, 0x2b, 0xaf,
  0xfd, 0xf7, 0x9d, 0x5a, 0x26, 0xc4, 0x30, 0xf7, 0xa9, 0xe2, 0x0a, 0x6d,
  0x04, 0x6d, 0xff, 0x2a, 0x16, 0xa0, 0xc7, 0xe8, 0x84, 0x8d, 0x04, 0xb4,
  0x5e, 0x88, 0x27, 0x24, 0xd8, 0x7a, 0x24, 0x65, 0x3c, 0x64, 0xda, 0x84,
  0x92, 0x08, 0x44, 0xca, 0x67, 0x43, 0xb7, 0x84, 0xe8, 0x08, 0xbb, 0x0c,
  0x80, 0x58, 0x0e, 0x50, 0x14, 0x1a, 0x1c, 0x44, 0x05, 0x86, 0xb5, 0xc5,
  0x42, 0xbc, 0xa2, 0x85, 0x31, 0x84, 0xe8, 0xa7, 0x8e, 0xe3, 0x61, 0x4e,
  0x00, 0xb7, 0xd1, 0x45, 0x03, 0x4a, 0x70, 0xaa, 0x85, 0x20, 0x17, 0x16,
  0xe7, 0x6e, 0x47, 0x4d, 0x36, 0xe2, 0x13, 0x8a, 0xd6, 0x21, 0xd5, 0x69,
  0x40, 0x41, 0x4d, 0xcb, 0xab, 0x6a, 0xed, 0x96, 0x4b, 0x88, 0x36, 0x12,
  0x17, 0xa0, 0x6f, 0x68, 0xd0, 0x86, 0x3a, 0x94, 0xa3, 0xee, 0x25, 0xd5,
  0xd0, 0xa8, 0x0c, 0x21, 0xde, 0x13, 0x6d, 0x21, 0xc9, 0x28, 0xc6, 0x90,
  0xc7, 0xf5, 0xc3, 0xb1, 0x88, 0x7c, 0x4a, 0x17, 0xe2, 0xac, 0x05, 0xa5,
  0xa3, 0xb4, 0xb0, 0x05, 0x01, 0x9d, 0x53, 0xa6, 0xe2, 0x94, 0xaf, 0x77,
  0xc6, 0xec, 0x73, 0xb9, 0xc4, 0x34, 0x29, 0x00, 0x19, 0x28, 0x3d, 0x0c,
  0xda, 0x6f, 0x1b, 0x90, 0xa4, 0x2f, 0xc6, 0x7c, 0x81, 0x10, 0xe5, 0x00,
  0x9e, 0xf0, 0x4c, 0xaf, 0x85, 0x18, 0x25, 0x9b, 0x68, 0x1e, 0xa1, 0x53,
  0x86, 0x72, 0x53, 0x88, 0x5a, 0x80, 0x78, 0xe4, 0x5e, 0x04, 0x1d, 0x13,
  0xe2, 0x34, 0x00, 0xdb, 0x51, 0xae, 0xa1, 0x74, 0x0b, 0xf1, 0xd9, 0x3a,
  0xd5, 0x08, 0xf2, 0x1b, 0x52, 0x9e, 0x10, 0xb9, 0x00, 0xc4, 0xa0, 0x14,
  0x43, 0x99, 0x10, 0x62, 0x16, 0x22, 0x80, 0x5e, 0xe8, 0x31, 0xae, 0x6d,
  0xd4, 0xda, 0x08, 0x60, 0x06, 0x26, 0x0c, 0x25, 0xce, 0xaa, 0x43, 0x22,
  0x80, 0x0f, 0xd0, 0x6a, 0x48, 0x31, 0xc0, 0xfc, 0x7d, 0xb8, 0xc0, 0x6d,
  0x28, 0x93, 0x00, 0x3f, 0x2d, 0xe8, 0x25, 0x34, 0x18, 0xd2, 0x1a, 0x80,
  0x6c, 0x00, 0x56, 0xc3, 0x4a, 0x43, 0xe9, 0x03, 0xf0, 0x59, 0x50, 0x03,
  0x73, 0x8d, 0x0c, 0xd8, 0x52, 0x11, 0xc0, 0x51, 0x00, 0x8a, 0x99, 0x3f,
  0x9c, 0x15, 0xad, 0x00, 0x5d, 0xa1, 0x51, 0x2d, 0x3a, 0x63, 0x1f, 0x77,
  0x4c, 0x69, 0x42, 0x3c, 0xe3, 0x12, 0x63, 0xe8, 0xa9, 0x61, 0xc4, 0x1e,
  0x21, 0x2a, 0x43, 0x50, 0x36, 0x8a, 0x57, 0x9f, 0x2d, 0x36, 0x59, 0x2f,
  0x57, 0xe8, 0x88, 0x81, 0x74, 0x29, 0x52, 0x04, 0x48, 0x5d, 0xc8, 0x5c,
  0x83, 0xf2, 0x35, 0x63, 0x2f, 0x18, 0xd1, 0x3d, 0x5d, 0xd6, 0x1b, 0x03,
  0x99, 0xd5, 0x2e, 0x21, 0x6e, 0x98, 0xcf, 0x23, 0x89, 0xaf, 0x68, 0xaf,
  0xa6, 0xe4, 0x1c, 0x41, 0x1d, 0x16, 0xc2, 0x4f, 0x52, 0x78, 0x73, 0x99,
  0x40, 0x1b, 0xd5, 0xe2, 0x80, 0x7c, 0xb4, 0xaa, 0x6e, 0x92, 0x2d, 0x4b,
  0x7b, 0x60, 0x16, 0xc3, 0xc8, 0xa5, 0x42, 0x5d, 0x53, 0x87, 0xc6, 0x35,
  0xa7, 0x29, 0xf5, 0xe8, 0x81, 0xca, 0x14, 0x25, 0xc4, 0x10, 0xdb, 0x9c,
  0x5b, 0x67, 0x2c, 0x55, 0x4c, 0x38, 0x3c, 0xf6, 0x59, 0xae, 0xb3, 0xfc,
  0x4f, 0x3d, 0x37, 0x95, 0xf3, 0xd4, 0xd3, 0xcf, 0x1c, 0x42, 0xf4, 0x51,
  0xc3, 0x49, 0x56, 0xf1, 0xff, 0xf1, 0x0b, 0xd2, 0x23, 0xab, 0x79, 0xf7,
  0x46, 0x72, 0xbd, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae,
  0x42, 0x60, 0x82
};
static const guchar digit_7_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xef, 0x9f, 0xd1, 0xb8, 0x00, 0x00, 0x01,
  0x8d, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xb5, 0x94, 0xb1, 0x4b, 0x55,
  0x51, 0x1c, 0xc7, 0x3f, 0xef, 0xe2, 0xab, 0x37, 0x89, 0x5b, 0x46, 0x82,
  0xfa, 0x30, 0x9c, 0x6a, 0xca, 0x41, 0xb0, 0x46, 0x9b, 0x04, 0xd1, 0xa5,
  0xa1, 0xa2, 0xa1, 0xad, 0x20, 0x1c, 0x8c, 0x88, 0xfe, 0x85, 0x08, 0x0a,
  0x0a, 0x0b, 0x6c, 0x88, 0xa0, 0x31, 0xa4, 0xa1, 0xa0, 0xa9, 0x21, 0xa1,
  0xd1, 0xa2, 0x24, 0x92, 0x82, 0x1e, 0x14, 0x08, 0x3a, 0xf8, 0xca, 0xf0,
  0x3d, 0xfc, 0x34, 0x78, 0xba, 0xdd, 0xc1, 0xfb, 0xe3, 0x19, 0xf6, 0xbb,
  0x70, 0x2f, 0x9c, 0xfb, 0xf9, 0x7c, 0xcf, 0x3d, 0xe7, 0xdc, 0x73, 0xe0,
  0x1f, 0xea, 0x03, 0x76, 0x7c, 0xf5, 0x65, 0x7b, 0x4d, 0x4f, 0xc2, 0x72,
  0x27, 0xe1, 0x45, 0x61, 0xcf, 0x3d, 0xfc, 0x47, 0xa1, 0x6b, 0xe7, 0xf1,
  0x98, 0x43, 0x25, 0xc0, 0x69, 0x86, 0x00, 0x68, 0xb1, 0xd9, 0xc9, 0xb4,
  0xd6, 0xdd, 0x74, 0xa7, 0x66, 0x45, 0xbe, 0x52, 0xeb, 0x2a, 0x8d, 0xef,
  0x63, 0xb2, 0xc2, 0x5d, 0x6a, 0x00, 0xbc, 0xe2, 0x26, 0xb4, 0x98, 0xe6,
  0x57, 0xf9, 0xc7, 0x3e, 0xc7, 0x33, 0x29, 0xbd, 0x69, 0x5d, 0xe4, 0x5a,
  0x34, 0xb6, 0x29, 0xec, 0xf1, 0x7b, 0x12, 0x2e, 0x8b, 0x2c, 0x46, 0x13,
  0xd4, 0x4d, 0x03, 0xef, 0x25, 0xfc, 0xb5, 0x99, 0xfc, 0x64, 0x38, 0xca,
  0xbf, 0x8d, 0xa3, 0x09, 0x6f, 0x7b, 0x5c, 0xe4, 0x7a, 0x84, 0x8f, 0xd0,
  0xae, 0xfa, 0x36, 0x09, 0xb7, 0x44, 0x3e, 0x72, 0x30, 0x5a, 0x99, 0x25,
  0xbc, 0x9a, 0xf0, 0x55, 0x7b, 0x44, 0x4e, 0x45, 0xf9, 0x33, 0xd8, 0xef,
  0x8f, 0x24, 0x5c, 0x12, 0x79, 0x1a, 0xe1, 0xbd, 0x34, 0x71, 0x21, 0xe1,
  0x2b, 0x1e, 0x90, 0x16, 0xfd, 0x91, 0xf0, 0x08, 0x27, 0xfc, 0x53, 0x17,
  0x44, 0xee, 0x44, 0xf8, 0x09, 0xb6, 0x6b, 0xae, 0x24, 0xfc, 0x8b, 0x55,
  0xd9, 0x2a, 0xfd, 0xc9, 0x80, 0x8c, 0x37, 0x78, 0x23, 0xcf, 0xbf, 0x22,
  0x32, 0x1f, 0xe5, 0x9f, 0xc5, 0xc3, 0x36, 0x13, 0xbe, 0x61, 0xb7, 0x6c,
  0x47, 0xcb, 0x95, 0xf1, 0x19, 0x1f, 0xe4, 0xf9, 0xf7, 0x45, 0x5e, 0x44,
  0xf9, 0xe7, 0x71, 0xc8, 0x76, 0x2e, 0x8c, 0x89, 0x4c, 0x96, 0xe3, 0x15,
  0xde, 0xe1, 0xc3, 0x1c, 0x6f, 0x98, 0xc9, 0x3a, 0xd5, 0x72, 0x61, 0x1c,
  0x7b, 0xdd, 0xca, 0x85, 0x39, 0x91, 0x27, 0xd1, 0x9e, 0x3e, 0x07, 0x17,
  0x0b, 0x81, 0x2f, 0xf3, 0x5b, 0xd9, 0x80, 0xd7, 0x2a, 0xbe, 0xf7, 0x6f,
  0x1d, 0x11, 0x19, 0x28, 0x17, 0x46, 0x71, 0xb0, 0x80, 0xaf, 0x5a, 0x91,
  0x46, 0x74, 0xcc, 0x8c, 0xc0, 0xc9, 0x42, 0xe3, 0x27, 0x84, 0xe5, 0x48,
  0x38, 0x0a, 0xc7, 0x0a, 0x8d, 0xdf, 0x00, 0xd6, 0xa2, 0x35, 0x78, 0xb6,
  0xcb, 0x11, 0x33, 0x1f, 0xf5, 0x50, 0xdf, 0xe5, 0xcd, 0x06, 0xfb, 0x53,
  0xbf, 0x01, 0xeb, 0x22, 0x5e, 0xc4, 0x4d, 0x09, 0xac, 0x25, 0x00, 0x00,
  0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_8_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x19, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0x00, 0x5d, 0xba, 0x86, 0x00, 0x00, 0x02,
  0x69, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xa5, 0x95, 0x49, 0x6c, 0x4d,
  0x61, 0x18, 0x86, 0x9f, 0xde, 0x72, 0xab, 0x31, 0x25, 0x6a, 0x88, 0x50,
  0x89, 0x10, 0x2c, 0x10, 0x0b, 0xba, 0x90, 0x88, 0x29, 0x62, 0x25, 0x36,
  0x34, 0xb1, 0x32, 0x6c, 0x44, 0x2c, 0x44, 0x1a, 0x5d, 0x18, 0x1a, 0x29,
  0x62, 0x4a, 0x6c, 0xb0, 0x12, 0xa5, 0xa2, 0xd1, 0x85, 0x2d, 0x41, 0x90,
  0x18, 0xd3, 0x50, 0x09, 0x42, 0x10, 0x34, 0xc4, 0x3c, 0x84, 0x1a, 0xab,
  0xd3, 0x7d, 0x2c, 0xce, 0xbd, 0xa7, 0xff, 0xb9, 0xb7, 0x6c, 0xfa, 0xdd,
  0xcd, 0x3d, 0xef, 0xf7, 0x3d, 0xe7, 0xfb, 0xcf, 0xf7, 0xbf, 0xe7, 0x3f,
  0xd0, 0xe7, 0x48, 0xb3, 0x86, 0x8b, 0xb4, 0x90, 0x41, 0xe4, 0x13, 0x4d,
  0x54, 0x33, 0xf2, 0x7f, 0xc0, 0x12, 0xbe, 0x60, 0xc1, 0xaf, 0x8b, 0xdd,
  0xa4, 0x7a, 0x07, 0x36, 0x20, 0x8e, 0xb3, 0xd6, 0x6b, 0x7e, 0xb4, 0xd3,
  0x36, 0x9f, 0x58, 0xef, 0x22, 0x8b, 0x44, 0x9a, 0x18, 0x54, 0x08, 0x54,
  0x62, 0xca, 0x6d, 0x76, 0x99, 0x1f, 0xe7, 0x1d, 0x2e, 0xd2, 0x98, 0x0f,
  0x0c, 0xe1, 0x1b, 0xee, 0xb7, 0xf7, 0x68, 0xb6, 0x44, 0x64, 0x5a, 0xc1,
  0xa2, 0x2a, 0x82, 0xa2, 0x0b, 0x1e, 0xf0, 0x52, 0x70, 0xbd, 0x51, 0xe4,
  0x64, 0x12, 0x69, 0xc2, 0xfa, 0xb8, 0x60, 0x7b, 0xf6, 0xc1, 0x0f, 0xc5,
  0xca, 0x1d, 0x91, 0x0f, 0x49, 0xe4, 0x37, 0xbe, 0x88, 0x0b, 0x46, 0x89,
  0x1c, 0xc7, 0x29, 0xb1, 0xd2, 0x16, 0xdd, 0x24, 0x11, 0x62, 0x7b, 0x5c,
  0xd0, 0x4f, 0x24, 0x8d, 0xe9, 0x58, 0xe9, 0x08, 0x90, 0xdc, 0xbc, 0x33,
  0x21, 0x3f, 0x19, 0x60, 0x39, 0xf4, 0x8b, 0x95, 0x67, 0x00, 0xef, 0x93,
  0x5d, 0x5e, 0xe1, 0xc3, 0xf8, 0x9e, 0x27, 0x44, 0x3a, 0x70, 0x56, 0xac,
  0xec, 0x12, 0x39, 0x95, 0x44, 0x1a, 0xb1, 0x26, 0x98, 0xd0, 0x3a, 0x11,
  0x0f, 0x66, 0xaf, 0x3e, 0x45, 0x3b, 0xb3, 0x24, 0x89, 0xcc, 0xc6, 0x81,
  0x41, 0x9f, 0x8c, 0x6b, 0x9d, 0x6d, 0xa7, 0xaa, 0x7f, 0x9c, 0x27, 0x72,
  0x93, 0xa2, 0xfc, 0xcd, 0x6c, 0xc0, 0xb1, 0x3e, 0x0e, 0x3a, 0xfd, 0x50,
  0xf5, 0xab, 0xf3, 0x45, 0x5a, 0x29, 0x2f, 0x34, 0xcc, 0x40, 0x9e, 0xe2,
  0x30, 0xcf, 0x25, 0xf6, 0xfd, 0xb5, 0xe3, 0xa3, 0x59, 0x55, 0xf5, 0x66,
  0xca, 0x15, 0x74, 0xe1, 0x04, 0x2f, 0xe7, 0x99, 0xe5, 0x9a, 0x33, 0x22,
  0x68, 0x17, 0xc5, 0x49, 0x60, 0x35, 0xe2, 0x4a, 0x7f, 0x65, 0x0b, 0x5b,
  0x03, 0xa8, 0xcb, 0x3d, 0xa6, 0x45, 0xae, 0x06, 0x53, 0x67, 0x21, 0x99,
  0x22, 0xf7, 0xc5, 0x45, 0x8d, 0x8e, 0xf0, 0x46, 0xa2, 0xd7, 0xcd, 0x68,
  0x66, 0x75, 0x3d, 0x4f, 0xf1, 0x19, 0xb7, 0xc7, 0xe9, 0xf7, 0x0e, 0x15,
  0x07, 0x78, 0x3a, 0x01, 0xdd, 0x8e, 0xdc, 0x5c, 0x11, 0x21, 0x1b, 0x71,
  0xa6, 0x99, 0x38, 0xb9, 0x45, 0xe4, 0x0d, 0x16, 0x5b, 0x97, 0x80, 0xaa,
  0x45, 0xea, 0x23, 0xe4, 0x0a, 0x36, 0x04, 0xa9, 0xe9, 0x22, 0x73, 0xd8,
  0x81, 0xc5, 0x5e, 0x08, 0xf4, 0xfb, 0x22, 0xef, 0x22, 0xe4, 0x17, 0xbe,
  0x0e, 0x52, 0xa5, 0x22, 0x03, 0x80, 0xaa, 0xd0, 0x32, 0xda, 0x1e, 0x58,
  0x53, 0x12, 0xaf, 0x6f, 0xff, 0x5c, 0x22, 0x8d, 0x25, 0x81, 0x9e, 0x73,
  0x73, 0x0a, 0xe8, 0x86, 0xf6, 0x60, 0xde, 0xa3, 0x01, 0x26, 0x01, 0x83,
  0xa1, 0x34, 0xd0, 0x5f, 0x66, 0xdd, 0x9c, 0x02, 0x9e, 0xc3, 0xa3, 0x20,
  0xb5, 0x18, 0xe0, 0x14, 0x5b, 0x39, 0x03, 0x0b, 0x02, 0xfd, 0x22, 0xc0,
  0xad, 0xe8, 0xff, 0x51, 0xdc, 0x1c, 0x2c, 0xe0, 0x6d, 0xce, 0x24, 0x96,
  0xdb, 0x12, 0xab, 0xdd, 0x4e, 0x15, 0x59, 0x15, 0x21, 0x15, 0x38, 0xd4,
  0x37, 0x01, 0xf4, 0xd3, 0x7a, 0x6b, 0xad, 0xf3, 0x7b, 0xa0, 0xed, 0x14,
  0x79, 0x4b, 0x3a, 0xd7, 0xf3, 0x0c, 0x56, 0x24, 0x4c, 0x92, 0x1f, 0x87,
  0x4d, 0x49, 0x37, 0x73, 0x7b, 0x96, 0x59, 0xc6, 0x2b, 0x9c, 0x98, 0x38,
  0x86, 0x7a, 0xe2, 0x85, 0x95, 0xd1, 0x42, 0x37, 0x25, 0x6d, 0x39, 0x86,
  0x7b, 0x88, 0x33, 0xdd, 0xeb, 0x75, 0x3f, 0xd8, 0x69, 0xc6, 0x56, 0xef,
  0x7a, 0xc4, 0xa5, 0xd1, 0xd0, 0xbb, 0x59, 0x59, 0x68, 0xfe, 0x62, 0x6a,
  0xf8, 0xdd, 0xcb, 0x21, 0x2e, 0x19, 0x1a, 0x18, 0xf3, 0xaf, 0x93, 0x3f,
  0xc5, 0x32, 0x8e, 0xd1, 0x9c, 0xfd, 0x54, 0xb4, 0xf2, 0x80, 0xb3, 0xac,
  0xa7, 0xac, 0xcf, 0x9f, 0xa0, 0xbf, 0x4d, 0x42, 0x16, 0x17, 0x9d, 0xa6,
  0xa3, 0xfa, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
  0x60, 0x82
};
static const guchar digit_9_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x19, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0x00, 0x5d, 0xba, 0x86, 0x00, 0x00, 0x02,
  0x79, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xa5, 0x95, 0x5f, 0x68, 0x8d,
  0x61, 0x1c, 0xc7, 0x3f, 0xe7, 0x98, 0xad, 0x6d, 0x42, 0x2d, 0xa1, 0x65,
  0x12, 0xb1, 0x30, 0x16, 0x99, 0xac, 0xb8, 0xa3, 0x91, 0xe1, 0x82, 0xdc,
  0xac, 0x84, 0x5d, 0x28, 0x47, 0x8a, 0x2b, 0x71, 0xa5, 0x64, 0x25, 0xca,
  0x8a, 0xcc, 0x8d, 0xa2, 0xa6, 0x5d, 0xe0, 0x82, 0x72, 0x21, 0xb5, 0x8b,
  0xe5, 0x6f, 0xfe, 0xcb, 0x85, 0x68, 0xc3, 0x34, 0x8c, 0xc9, 0x59, 0xcc,
  0x19, 0x67, 0x1f, 0x17, 0xe7, 0xdf, 0x73, 0xce, 0xc6, 0x8d, 0xdf, 0x5b,
  0xef, 0xfb, 0xbc, 0xdf, 0xe7, 0xf7, 0x79, 0xde, 0xe7, 0xf7, 0xfc, 0x9e,
  0xdf, 0xf3, 0xc2, 0x7f, 0xdb, 0x3c, 0x8e, 0x73, 0x8f, 0xcf, 0x88, 0xf4,
  0x71, 0x83, 0x63, 0x54, 0xff, 0xcb, 0xbd, 0x8a, 0x9b, 0x38, 0xc6, 0x75,
  0x95, 0x69, 0x63, 0x03, 0xab, 0xf9, 0x81, 0x13, 0xdd, 0xed, 0x75, 0xdf,
  0xfb, 0xcb, 0x84, 0x6f, 0xbc, 0xec, 0x36, 0x4b, 0x45, 0x12, 0xac, 0x1f,
  0x0d, 0x6c, 0x62, 0x04, 0x9b, 0xfc, 0x62, 0xa1, 0xf5, 0xba, 0x51, 0x24,
  0xc9, 0xda, 0x7c, 0xa0, 0x82, 0x38, 0x1e, 0xf4, 0x6f, 0xb6, 0x5f, 0x64,
  0x90, 0xaa, 0x10, 0x69, 0xc7, 0x0d, 0x81, 0xcb, 0xb0, 0x97, 0x6c, 0xf5,
  0x61, 0xa0, 0x6c, 0x15, 0xb9, 0x93, 0x03, 0x66, 0x30, 0x52, 0x6c, 0x4f,
  0x00, 0xac, 0x14, 0x31, 0x62, 0x4b, 0x56, 0x1b, 0xb0, 0x42, 0x64, 0x5d,
  0x06, 0xd9, 0x87, 0x9b, 0x83, 0x11, 0xdb, 0x44, 0xba, 0x39, 0xc9, 0xcf,
  0xa8, 0x0f, 0xb2, 0x6a, 0x8b, 0xc8, 0xcd, 0x0c, 0x72, 0x15, 0xcf, 0x07,
  0x48, 0x83, 0xc8, 0x66, 0xe0, 0x30, 0xee, 0xca, 0xaa, 0x5f, 0x2c, 0x96,
  0x24, 0x15, 0x29, 0xe4, 0x35, 0xbe, 0x08, 0x90, 0x4a, 0x91, 0x4a, 0x60,
  0x11, 0x2e, 0x08, 0xf4, 0x35, 0x22, 0x4d, 0x29, 0x64, 0x18, 0xbf, 0x07,
  0x5d, 0x25, 0x22, 0x11, 0xa0, 0x08, 0x27, 0x04, 0xfa, 0x11, 0x91, 0x33,
  0x10, 0x05, 0xc6, 0x43, 0x69, 0xb0, 0x7c, 0xbf, 0x01, 0x4c, 0x35, 0x12,
  0x81, 0x5e, 0x0b, 0x50, 0x9d, 0x42, 0x80, 0x78, 0xd0, 0x55, 0x06, 0x50,
  0x02, 0x4c, 0x84, 0xc9, 0x81, 0x3e, 0x07, 0x60, 0x66, 0x0a, 0x19, 0x80,
  0x0f, 0x41, 0xd7, 0x4c, 0x80, 0xf9, 0xc0, 0x2a, 0x58, 0x18, 0xe8, 0x53,
  0xd3, 0xb7, 0x28, 0xf0, 0x9c, 0x30, 0x4b, 0xd4, 0x03, 0x34, 0x51, 0xce,
  0x21, 0xd8, 0x58, 0xf8, 0xf5, 0xd2, 0x6c, 0x5e, 0x1a, 0x83, 0x30, 0x1f,
  0x59, 0x94, 0xde, 0xc3, 0xb3, 0xf3, 0x96, 0x25, 0x99, 0x52, 0x01, 0x98,
  0xc6, 0xef, 0xa8, 0xcf, 0x82, 0xce, 0x8b, 0xce, 0xb2, 0xcc, 0x06, 0xbb,
  0xf3, 0x76, 0xda, 0xf7, 0xd4, 0xf6, 0x4c, 0xdb, 0x69, 0x5c, 0x9c, 0x37,
  0x62, 0xc6, 0xfa, 0x83, 0xf6, 0x1b, 0x91, 0xfe, 0x0c, 0x52, 0x4e, 0x0f,
  0x2e, 0xb7, 0xb7, 0x00, 0x78, 0x62, 0x4d, 0xf0, 0xd6, 0x25, 0x72, 0x3f,
  0x17, 0x5b, 0x35, 0x71, 0x2c, 0x73, 0xaf, 0x9d, 0x7e, 0x32, 0xe9, 0x37,
  0x3b, 0x6d, 0xb6, 0xd8, 0xa9, 0x01, 0x72, 0x56, 0xa4, 0x23, 0x2c, 0x80,
  0xe9, 0x5c, 0x19, 0x5d, 0xc4, 0xf5, 0x01, 0xb2, 0x43, 0xe4, 0x40, 0x61,
  0x6d, 0xd6, 0x72, 0x9a, 0xc7, 0x0c, 0x21, 0x43, 0x3c, 0xe3, 0x05, 0xee,
  0x09, 0x90, 0x2a, 0x91, 0xba, 0x8c, 0xeb, 0x5a, 0x9a, 0x29, 0x2f, 0xc0,
  0x8b, 0x78, 0x89, 0x9d, 0xf9, 0x91, 0x7c, 0xcc, 0xec, 0x16, 0x88, 0x21,
  0x3f, 0x69, 0xa7, 0x91, 0x48, 0x16, 0xb8, 0x80, 0x75, 0x85, 0x75, 0x79,
  0x22, 0x37, 0x62, 0x2c, 0x3b, 0xfb, 0x61, 0xae, 0xd1, 0x42, 0x2b, 0xaf,
  0x70, 0x52, 0x90, 0xab, 0x47, 0x8e, 0x93, 0x44, 0x78, 0x38, 0xc5, 0x70,
  0x8b, 0x47, 0x5d, 0x62, 0x24, 0x1b, 0x78, 0x4d, 0x50, 0xfb, 0xbf, 0x5c,
  0x2a, 0x72, 0x2a, 0x9c, 0x77, 0x0c, 0x63, 0xaa, 0xf6, 0x79, 0xc9, 0xe3,
  0xb6, 0x79, 0x3b, 0x2f, 0x3f, 0x3b, 0x45, 0xde, 0xe5, 0x55, 0x48, 0x0e,
  0x19, 0x6d, 0x09, 0xb7, 0xa7, 0x0e, 0xbf, 0xda, 0x8c, 0x73, 0xf4, 0xdf,
  0x47, 0x74, 0x17, 0x75, 0x9c, 0x83, 0x11, 0xb6, 0xf0, 0x38, 0xb7, 0x94,
  0x69, 0xeb, 0x20, 0xce, 0x72, 0x16, 0x31, 0x9b, 0x29, 0x44, 0x89, 0xf3,
  0x8a, 0x2e, 0x3a, 0xb8, 0x8b, 0xd0, 0x47, 0x03, 0x4f, 0x0b, 0x07, 0x6b,
  0x24, 0x31, 0xe6, 0x01, 0x2e, 0x5f, 0xd9, 0xcb, 0xf8, 0x7c, 0xe7, 0x48,
  0xf6, 0x59, 0xc3, 0x32, 0x56, 0x50, 0xcd, 0x5c, 0xa6, 0x00, 0xf2, 0x96,
  0x87, 0xdc, 0xa2, 0x8d, 0xc1, 0xff, 0xff, 0x03, 0xf1, 0x07, 0x0e, 0x56,
  0xb9, 0x3c, 0x2f, 0x52, 0x38, 0xff, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
  0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
static const guchar digit_dot_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x22,
  0x08, 0x04, 0x00, 0x00, 0x00, 0xc1, 0xda, 0xf0, 0x2a, 0x00, 0x00, 0x00,
  0x3d, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0x63, 0x60, 0x18, 0x05, 0xa3,
  0x80, 0x10, 0x60, 0x64, 0x60, 0x60, 0xd0, 0xc0, 0x22, 0x7e, 0x83, 0x91,
  0x81, 0x81, 0xe1, 0x3f, 0x36, 0x0d, 0x2c, 0x10, 0x1a, 0x59, 0xd3, 0x0d,
  0xb8, 0x51, 0xff, 0x51, 0x35, 0x31, 0x32, 0x30, 0x30, 0x30, 0x30, 0x32,
  0xe1, 0xb2, 0x9c, 0x1e, 0x12, 0x2c, 0x48, 0x2e, 0x21, 0x4e, 0x07, 0x4e,
  0x00, 0x00, 0xd8, 0x12, 0x05, 0x19, 0x3a, 0x02, 0xff, 0xdf, 0x00, 0x00,
  0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char development_snapshot_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0xdc, 0x00, 0x00, 0x00, 0x18,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x91, 0x23, 0x93, 0x23, 0x00, 0x00, 0x09,
  0x9e, 0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0xed, 0x5c, 0x07, 0x90, 0x15,
  0x35, 0x18, 0x0e, 0x1d, 0xe9, 0x5d, 0x40, 0xc1, 0x82, 0x20, 0x4d, 0x04,
  0x81, 0xa3, 0x88, 0x08, 0xa8, 0xf4, 0x66, 0xa3, 0x08, 0x23, 0x0a, 0x07,
  0x08, 0x83, 0x74, 0x38, 0x74, 0x28, 0x3a, 0xa0, 0xd2, 0x95, 0x5e, 0xa4,
  0x37, 0x95, 0xa2, 0x80, 0x80, 0xa8, 0x28, 0x8c, 0x20, 0x88, 0x85, 0xa2,
  0x20, 0x1d, 0x94, 0xde, 0x8b, 0xdc, 0x71, 0xb4, 0x23, 0xe6, 0xdb, 0x64,
  0xdf, 0xe6, 0xed, 0xcb, 0xbe, 0xb7, 0xd9, 0x7b, 0xcf, 0x91, 0x99, 0xcd,
  0xcc, 0x3f, 0xdc, 0x25, 0xd9, 0x3f, 0x7f, 0xfe, 0x96, 0xff, 0xff, 0x93,
  0x83, 0x10, 0xbf, 0xf9, 0xcd, 0x6f, 0x7e, 0xd3, 0x68, 0x54, 0x01, 0x7e,
  0xf3, 0xdb, 0xff, 0x5a, 0x5f, 0x68, 0x18, 0xb8, 0xc9, 0xe0, 0x34, 0x83,
  0x0d, 0x0c, 0x06, 0x31, 0x28, 0xf0, 0x7f, 0x63, 0x20, 0xfd, 0xc6, 0x02,
  0xdf, 0xe0, 0xfc, 0x76, 0x37, 0xe8, 0x4b, 0x10, 0x11, 0x26, 0xdc, 0x58,
  0x4d, 0xe8, 0xa9, 0x4f, 0x09, 0x5d, 0x3f, 0x8a, 0xd0, 0x81, 0xaf, 0x10,
  0x9a, 0x3f, 0xa7, 0x41, 0xdc, 0x35, 0x06, 0xf1, 0x3e, 0x03, 0xef, 0x9a,
  0x96, 0x8d, 0x41, 0x59, 0x06, 0x8d, 0x25, 0xf0, 0x0d, 0x2e, 0x76, 0xfa,
  0xe2, 0x8a, 0xdf, 0x4a, 0x83, 0xb3, 0x43, 0xd2, 0x4a, 0x42, 0x3b, 0xd4,
  0x0f, 0x10, 0xd9, 0xd1, 0x37, 0xb8, 0xbb, 0x43, 0xc1, 0xb2, 0x66, 0x26,
  0xb4, 0xcc, 0x03, 0x84, 0x36, 0x8a, 0xf3, 0xf9, 0xf3, 0x1f, 0xe8, 0x8b,
  0x2b, 0x7e, 0x87, 0x10, 0x91, 0x86, 0xf0, 0x13, 0xad, 0x69, 0x35, 0x7e,
  0xc2, 0xc9, 0xe3, 0xf1, 0x0d, 0x8c, 0x39, 0xc9, 0x0c, 0x0a, 0xfa, 0x06,
  0xe7, 0x87, 0x50, 0x3e, 0x3f, 0xf4, 0xf1, 0xab, 0x26, 0x21, 0x57, 0x6b,
  0x26, 0x72, 0x37, 0x3a, 0xaa, 0xa3, 0x35, 0x7e, 0xed, 0x4b, 0x42, 0xef,
  0xcd, 0x6d, 0xcc, 0x79, 0x47, 0x7c, 0x5f, 0x9b, 0xc1, 0x1a, 0x06, 0x17,
  0x84, 0x21, 0x9a, 0xb0, 0x87, 0xc1, 0xdb, 0x0c, 0x3e, 0x54, 0xe4, 0x86,
  0xbf, 0xda, 0x68, 0x98, 0x64, 0x1b, 0xdf, 0xec, 0x02, 0x6f, 0xfa, 0x08,
  0x1b, 0x2c, 0xcc, 0x60, 0x14, 0x83, 0xdd, 0x0c, 0x92, 0x6c, 0xb0, 0x5b,
  0x8c, 0x15, 0x0a, 0x93, 0xc7, 0xae, 0x67, 0x90, 0x28, 0xc1, 0x19, 0x06,
  0xe3, 0x45, 0xd8, 0xa0, 0x9a, 0x7f, 0x84, 0xc1, 0x55, 0x09, 0x40, 0xfb,
  0x6b, 0x0c, 0x7e, 0xb1, 0xe1, 0x39, 0x26, 0xf0, 0x64, 0x91, 0x68, 0x75,
  0xb3, 0x57, 0x27, 0x3a, 0xbf, 0x65, 0x70, 0x45, 0x82, 0x53, 0x0c, 0xa6,
  0x99, 0xe3, 0x0a, 0xfe, 0x38, 0x29, 0x42, 0x2d, 0x06, 0x4b, 0x19, 0x1c,
  0x65, 0x70, 0x83, 0x41, 0x8a, 0x04, 0xc9, 0x82, 0xb6, 0x23, 0x1e, 0xe8,
  0x00, 0xbf, 0x46, 0x33, 0xd8, 0xc4, 0xe0, 0x24, 0x83, 0xeb, 0x12, 0x20,
  0x45, 0xd9, 0xc6, 0xa0, 0x0b, 0x83, 0x34, 0x1e, 0x65, 0xa1, 0x45, 0xb7,
  0x82, 0x1f, 0xe1, 0xe8, 0xd6, 0xd1, 0x23, 0xd7, 0xfc, 0x0e, 0xa7, 0xb4,
  0x60, 0xc2, 0x68, 0x9c, 0x78, 0x5b, 0xc6, 0x59, 0x73, 0x86, 0xb4, 0x35,
  0xe6, 0x6c, 0x64, 0xd0, 0x9d, 0xc1, 0x9d, 0x5a, 0xe5, 0x08, 0x5d, 0x3d,
  0x8c, 0xd0, 0xf3, 0x4b, 0xb9, 0x41, 0xfe, 0x39, 0x83, 0xd0, 0xb7, 0x5a,
  0x11, 0x9a, 0x2e, 0xad, 0x31, 0x6f, 0xc9, 0xd8, 0xce, 0xd6, 0xb7, 0xbf,
  0x4c, 0x0c, 0xac, 0x51, 0x42, 0xac, 0x01, 0x65, 0x3a, 0x37, 0xb1, 0x1b,
  0x1f, 0xff, 0xf1, 0xc3, 0x80, 0xc1, 0x45, 0xc4, 0x1b, 0x86, 0x76, 0x08,
  0xe1, 0x62, 0xa1, 0x3c, 0x84, 0x8e, 0x8c, 0x27, 0x74, 0xd7, 0x74, 0x42,
  0x13, 0x57, 0x72, 0xc0, 0xcf, 0xe8, 0x2b, 0xc8, 0x9d, 0x06, 0x84, 0x51,
  0x53, 0x85, 0xe7, 0xd9, 0x0a, 0x84, 0x7e, 0x3f, 0x92, 0xd0, 0xab, 0x2b,
  0x08, 0x3d, 0xfd, 0x19, 0xa1, 0xe3, 0xba, 0xf0, 0x70, 0x81, 0x8d, 0xad,
  0xb3, 0xcf, 0x07, 0x7f, 0xfa, 0xb7, 0x20, 0xf4, 0xf0, 0x3c, 0x42, 0xff,
  0x59, 0xce, 0x69, 0x2e, 0x92, 0x9f, 0xe3, 0x69, 0xf7, 0x1c, 0xa1, 0x3f,
  0x4f, 0xe0, 0x78, 0x8e, 0x2e, 0xe4, 0x78, 0xee, 0xc9, 0x68, 0x8c, 0x8d,
  0x10, 0xb4, 0x76, 0x77, 0xb9, 0x57, 0xa5, 0xac, 0xea, 0x94, 0x27, 0xf4,
  0x9b, 0x0f, 0x08, 0xbd, 0xfc, 0x05, 0xa1, 0x27, 0x3f, 0x21, 0x74, 0x6a,
  0x8f, 0x00, 0x9d, 0x8e, 0xe9, 0x81, 0xc2, 0xe0, 0xda, 0x82, 0x86, 0xa7,
  0x19, 0x0d, 0x4b, 0x06, 0x12, 0xfa, 0xf7, 0x02, 0x42, 0xaf, 0xb3, 0x1c,
  0xfe, 0xf6, 0x5a, 0x4e, 0x0b, 0x68, 0xc2, 0xde, 0xa4, 0xef, 0x74, 0xe8,
  0x18, 0x63, 0x3a, 0xed, 0x8d, 0x63, 0x09, 0x3d, 0xc1, 0xc6, 0x92, 0x57,
  0xf1, 0x14, 0xe5, 0xb7, 0x49, 0x84, 0xbe, 0xd1, 0x38, 0x80, 0x37, 0xc1,
  0x09, 0x77, 0x04, 0x59, 0xc4, 0x92, 0x6e, 0x1d, 0x3d, 0x72, 0xcd, 0xef,
  0x48, 0xc2, 0x48, 0xcb, 0xe0, 0xa7, 0x56, 0xb5, 0xac, 0x39, 0x3f, 0x8c,
  0x31, 0xe6, 0xc0, 0xcb, 0xdc, 0x7e, 0xb3, 0x19, 0xa1, 0x29, 0x6b, 0xd5,
  0x0b, 0x2d, 0x1e, 0xc8, 0xf1, 0x55, 0x2a, 0x11, 0xdc, 0x5f, 0xfc, 0xbe,
  0xa0, 0x13, 0xb2, 0x11, 0x94, 0xea, 0xec, 0x62, 0x3e, 0xd6, 0xb5, 0x89,
  0x31, 0xe6, 0x0a, 0xaf, 0x03, 0xed, 0xf0, 0x48, 0x17, 0x21, 0x84, 0x0b,
  0xcb, 0x9c, 0x99, 0x00, 0x61, 0x3c, 0x55, 0x56, 0xcd, 0x2c, 0x14, 0x89,
  0x54, 0xdf, 0x7c, 0x3b, 0x5c, 0xbd, 0xee, 0xf4, 0x9e, 0xa1, 0x73, 0x37,
  0x8c, 0x26, 0x74, 0x4c, 0x67, 0x35, 0x9e, 0xe1, 0x1d, 0x0c, 0x1c, 0x87,
  0x18, 0x54, 0xd0, 0xd8, 0xeb, 0x73, 0x6e, 0xe9, 0x1c, 0xdd, 0x49, 0xdb,
  0xe0, 0x0e, 0xb4, 0xa9, 0xe3, 0x4c, 0x83, 0xe2, 0x3b, 0x1d, 0x3a, 0x0e,
  0x47, 0xaa, 0x13, 0xc0, 0x59, 0xb1, 0x39, 0x7f, 0xe9, 0xe0, 0x36, 0x65,
  0x11, 0x63, 0xba, 0x75, 0xf4, 0x28, 0x6a, 0x06, 0x87, 0xd6, 0xfa, 0xfe,
  0x7c, 0xd6, 0x1c, 0x78, 0x19, 0x5c, 0x19, 0x94, 0x2f, 0x46, 0xe8, 0xad,
  0xaf, 0x78, 0x1f, 0x3c, 0x49, 0xe9, 0xa2, 0x84, 0xc2, 0x1b, 0xe0, 0x94,
  0x32, 0xe7, 0xc2, 0x3b, 0x01, 0xe7, 0xbe, 0x59, 0x21, 0x27, 0xe4, 0x3e,
  0x81, 0x7b, 0x51, 0xc3, 0x38, 0xde, 0x7f, 0x73, 0x0d, 0xa1, 0xf9, 0x72,
  0x10, 0xaa, 0x83, 0x57, 0x41, 0xfb, 0x18, 0xcc, 0x35, 0x99, 0x04, 0x61,
  0xf4, 0x7b, 0x99, 0xd0, 0x5c, 0x59, 0x39, 0xe0, 0xd4, 0x30, 0x05, 0x04,
  0x66, 0x09, 0x0f, 0xe5, 0xaa, 0x70, 0x04, 0x68, 0x5d, 0x5b, 0x6f, 0xbe,
  0x0a, 0x0e, 0xce, 0x31, 0x70, 0xdc, 0x62, 0x30, 0x57, 0x63, 0xaf, 0xd3,
  0xdd, 0xae, 0x7b, 0x68, 0x6e, 0x58, 0x87, 0xa4, 0x92, 0x71, 0xf2, 0xfe,
  0xd9, 0xd6, 0x3c, 0x38, 0x80, 0xdc, 0xd9, 0x08, 0x4d, 0x9b, 0x86, 0xff,
  0x8b, 0x22, 0x40, 0x93, 0xaa, 0xce, 0x8a, 0x1b, 0x81, 0x0e, 0xec, 0x93,
  0xce, 0xe8, 0x4d, 0x68, 0xbd, 0x4a, 0x7c, 0x6f, 0x38, 0xe1, 0xfb, 0xbc,
  0x64, 0xcd, 0x3b, 0xc2, 0x4f, 0xa1, 0x14, 0x1d, 0xdc, 0xa6, 0x2c, 0x62,
  0x49, 0x77, 0x6a, 0xf5, 0xc8, 0x4b, 0x48, 0x69, 0xb6, 0x22, 0x19, 0xd2,
  0x05, 0x5f, 0x19, 0xc0, 0xe0, 0xe6, 0xf4, 0xb5, 0xfa, 0x5e, 0x7d, 0x36,
  0x90, 0xc7, 0x6c, 0x6e, 0x5c, 0xc5, 0xea, 0x9f, 0xd6, 0xc3, 0xe8, 0xdf,
  0x0f, 0x23, 0x33, 0xfb, 0xf6, 0xce, 0x0c, 0xac, 0x53, 0x09, 0xb1, 0xf0,
  0xc2, 0x01, 0xbc, 0x7f, 0xd5, 0x50, 0xbe, 0x51, 0x0d, 0xbc, 0x2a, 0xda,
  0xf7, 0xc0, 0x43, 0x99, 0x7d, 0x1f, 0xf7, 0x32, 0xfa, 0xee, 0x30, 0xe8,
  0x2f, 0xf2, 0xa1, 0x3b, 0xb3, 0xfa, 0x58, 0xe3, 0x08, 0x0b, 0xec, 0x78,
  0x10, 0xea, 0x34, 0xa8, 0xcc, 0x15, 0xa3, 0x64, 0x11, 0x42, 0x77, 0x4c,
  0xb1, 0xc6, 0xd6, 0x0c, 0x0b, 0x9d, 0x8f, 0x53, 0x08, 0x0e, 0xa9, 0xec,
  0x83, 0xc1, 0xfd, 0x08, 0xa1, 0xe0, 0xfd, 0x32, 0x65, 0x20, 0xb4, 0x46,
  0x19, 0xab, 0x1f, 0x8e, 0xc5, 0xcc, 0xfb, 0x34, 0xf6, 0xba, 0xcd, 0xbe,
  0xee, 0xb6, 0xc9, 0x84, 0xc2, 0x59, 0x65, 0x66, 0x74, 0xd6, 0x7c, 0x4c,
  0x89, 0xdf, 0x6d, 0x91, 0x20, 0x19, 0x21, 0x98, 0x39, 0xaf, 0x4a, 0xc9,
  0xc0, 0x1d, 0xec, 0x3c, 0x06, 0xcf, 0x30, 0x68, 0x2a, 0x01, 0xf1, 0x40,
  0xc7, 0x4c, 0x09, 0x1a, 0x32, 0xe8, 0x9b, 0x31, 0xbd, 0x35, 0x0f, 0x21,
  0xa0, 0x93, 0x51, 0x44, 0x92, 0x45, 0x6a, 0xe8, 0x06, 0xae, 0x46, 0x82,
  0x6e, 0x9c, 0x64, 0x76, 0xba, 0x53, 0xab, 0x47, 0x3a, 0x45, 0x13, 0x7b,
  0x2b, 0x83, 0xb8, 0xd6, 0x9c, 0x83, 0x78, 0x17, 0x1b, 0x83, 0x47, 0x36,
  0xfb, 0xcc, 0x9c, 0x05, 0x50, 0xaa, 0x68, 0x30, 0xc3, 0x58, 0xdf, 0x79,
  0x84, 0x91, 0xf2, 0x3a, 0x15, 0x8b, 0x1b, 0xfd, 0x63, 0x81, 0x17, 0x31,
  0xb1, 0x74, 0x7a, 0xdc, 0xd0, 0xc0, 0xab, 0xa2, 0xfd, 0x1a, 0xf2, 0x1f,
  0xdb, 0x3a, 0x33, 0xa4, 0xbd, 0xcc, 0x96, 0x43, 0x5c, 0xc4, 0xe2, 0x76,
  0x3c, 0x70, 0x2e, 0x42, 0xc1, 0xa1, 0x1c, 0x3b, 0xeb, 0x56, 0x0c, 0x39,
  0xdd, 0x83, 0xe6, 0xc3, 0xa3, 0xaa, 0x72, 0x4a, 0x91, 0x7f, 0x6d, 0x72,
  0xca, 0x13, 0x35, 0xf7, 0x7a, 0xde, 0x8e, 0x23, 0x3d, 0xa7, 0x73, 0x3b,
  0xc2, 0x72, 0x27, 0xef, 0xea, 0xd6, 0xe0, 0x36, 0x7f, 0x14, 0xec, 0x50,
  0xe7, 0xf6, 0xe3, 0xf9, 0x4d, 0x1a, 0xfe, 0xcd, 0x31, 0xf1, 0xf0, 0x21,
  0x97, 0x4a, 0x67, 0x5c, 0xd0, 0xd1, 0x83, 0xc1, 0x59, 0xf0, 0x09, 0x4e,
  0x09, 0x06, 0xf4, 0x42, 0x0d, 0x77, 0x61, 0x5f, 0x24, 0x59, 0xa4, 0x86,
  0x6e, 0x81, 0x7b, 0xa7, 0xb8, 0x2f, 0x0b, 0xa1, 0x27, 0xb5, 0x7a, 0x94,
  0x1a, 0x83, 0xeb, 0x59, 0x5a, 0x52, 0x00, 0x84, 0x87, 0x50, 0x16, 0x24,
  0xa8, 0x91, 0x8e, 0xe7, 0x73, 0x4b, 0x02, 0x5e, 0xc7, 0x28, 0x1e, 0x98,
  0xfd, 0xc8, 0x6f, 0x58, 0xdf, 0x09, 0xc4, 0xe0, 0xf8, 0x1d, 0x09, 0x71,
  0x96, 0x4c, 0xda, 0x78, 0x95, 0x06, 0x97, 0xb4, 0xd2, 0xea, 0xcb, 0x91,
  0x25, 0x70, 0x92, 0x9a, 0xad, 0x32, 0xfa, 0xcc, 0x71, 0x18, 0xbb, 0x03,
  0x9e, 0x8c, 0x62, 0x7e, 0xbd, 0xbc, 0x39, 0x42, 0xbd, 0x9f, 0x62, 0x7e,
  0x3a, 0x87, 0xfe, 0xf4, 0xa2, 0xf8, 0xa4, 0x34, 0x38, 0x5d, 0x1e, 0x2a,
  0x70, 0x64, 0x08, 0x83, 0xdf, 0xad, 0xc1, 0x6d, 0x81, 0x81, 0x43, 0x69,
  0xec, 0x6b, 0xa3, 0xd0, 0x83, 0x5c, 0x27, 0x67, 0x56, 0xe3, 0xdb, 0x73,
  0x0c, 0x2a, 0x7a, 0xa1, 0xa3, 0x7b, 0x73, 0x42, 0xcf, 0x2c, 0xd6, 0xcf,
  0xb3, 0x22, 0xc9, 0x22, 0x0a, 0x74, 0x67, 0x74, 0xa2, 0x3b, 0x4a, 0x7a,
  0xa4, 0x6d, 0x70, 0xd9, 0x11, 0xe6, 0xf4, 0x78, 0xde, 0x9a, 0x03, 0x2f,
  0x02, 0x65, 0x81, 0x91, 0x44, 0x52, 0x16, 0x33, 0xfc, 0x44, 0x79, 0xbc,
  0xa7, 0x84, 0xe3, 0xf8, 0x22, 0xee, 0x85, 0x10, 0x16, 0xe0, 0xf7, 0xf9,
  0x09, 0xc6, 0xbc, 0x44, 0x4d, 0xbc, 0x4a, 0x83, 0x4b, 0x0c, 0x65, 0x54,
  0x65, 0x69, 0x3f, 0x71, 0x88, 0xef, 0x35, 0x18, 0x55, 0x0c, 0x21, 0xa1,
  0xed, 0x74, 0xd7, 0x51, 0x96, 0x70, 0x7c, 0xd6, 0xe5, 0xa1, 0x2e, 0x7e,
  0xb7, 0x06, 0x57, 0x1a, 0x25, 0x6e, 0x9c, 0x40, 0x38, 0x79, 0xd6, 0xbe,
  0xcf, 0xc3, 0x3c, 0xf9, 0x5b, 0x14, 0xb5, 0x9e, 0x78, 0xc4, 0xf8, 0xfe,
  0x67, 0x5d, 0x3a, 0xba, 0x35, 0x0b, 0xe6, 0xf7, 0x82, 0x04, 0x5e, 0x38,
  0xf2, 0xc0, 0x43, 0x95, 0x2c, 0x6e, 0xc5, 0x8a, 0xee, 0x28, 0xeb, 0x91,
  0x2b, 0x83, 0xcb, 0xcf, 0xe0, 0xbb, 0x6c, 0x99, 0x79, 0x42, 0x6f, 0xce,
  0x69, 0x5e, 0x9d, 0x1b, 0x87, 0x1c, 0x4f, 0x3f, 0xf6, 0x50, 0xc4, 0x37,
  0x99, 0xbd, 0x90, 0x58, 0xca, 0x0c, 0x69, 0x51, 0x93, 0x7b, 0x29, 0xfc,
  0x5c, 0xbf, 0x92, 0x31, 0x6f, 0x81, 0x26, 0x5e, 0x15, 0xed, 0x49, 0xb2,
  0xc7, 0xc3, 0xb1, 0xcf, 0xfa, 0x66, 0x49, 0x7b, 0x9a, 0x57, 0x59, 0x2f,
  0x14, 0x48, 0x78, 0xb8, 0x90, 0x35, 0xb6, 0x7d, 0x4a, 0x54, 0x0d, 0x4e,
  0x97, 0x87, 0xd1, 0x30, 0xb8, 0x4c, 0x0e, 0x46, 0x87, 0x13, 0xfa, 0x45,
  0x06, 0x5f, 0xa3, 0x80, 0x51, 0x38, 0x2f, 0x3f, 0x21, 0xe4, 0x0a, 0xdd,
  0xd6, 0xf1, 0x81, 0xe7, 0x7d, 0x5a, 0x74, 0x20, 0x67, 0x37, 0x7f, 0x47,
  0xb8, 0x27, 0xee, 0xb0, 0xbc, 0xf0, 0x50, 0x25, 0x8b, 0x2b, 0xb1, 0xa2,
  0x3b, 0x4a, 0x7a, 0x94, 0xc9, 0x8d, 0xc1, 0x75, 0x12, 0xc8, 0x13, 0x51,
  0x35, 0x5c, 0x37, 0xc2, 0x1a, 0xdf, 0x39, 0x35, 0x10, 0x1f, 0xef, 0x1c,
  0xf6, 0x5a, 0x48, 0x88, 0x88, 0xa4, 0x72, 0x24, 0x3c, 0x91, 0x28, 0x79,
  0x77, 0x94, 0x00, 0x97, 0x83, 0x29, 0x28, 0xe7, 0xca, 0x25, 0x55, 0xfc,
  0x8b, 0x50, 0x43, 0xe4, 0x3b, 0x0d, 0x34, 0xf1, 0xaa, 0x68, 0xdf, 0x3d,
  0x22, 0xde, 0xea, 0x9b, 0xd9, 0x3b, 0xf0, 0x3d, 0xee, 0x79, 0x06, 0xe3,
  0x67, 0x9c, 0xd0, 0x2e, 0x92, 0x5d, 0x38, 0x9b, 0x0e, 0xe0, 0x01, 0xca,
  0xd6, 0xe6, 0xd8, 0x88, 0xf8, 0xa8, 0x1a, 0x9c, 0x2e, 0x0f, 0xb5, 0x0d,
  0x4e, 0x0e, 0x59, 0x51, 0xa8, 0x10, 0xc5, 0x84, 0x74, 0x36, 0x1d, 0x98,
  0x2f, 0x41, 0x17, 0x11, 0x7e, 0x21, 0xf7, 0xb9, 0x88, 0x42, 0x85, 0xfc,
  0xbc, 0xcf, 0x8b, 0xe2, 0xca, 0x34, 0x88, 0x3b, 0xc8, 0xc1, 0x0e, 0x38,
  0x2a, 0x78, 0x90, 0xc5, 0x8e, 0x58, 0xd1, 0xed, 0x45, 0x8f, 0xdc, 0xf0,
  0x3b, 0x68, 0x21, 0x54, 0x6d, 0x70, 0x82, 0x75, 0x6c, 0xc0, 0x17, 0x91,
  0x43, 0x1e, 0x1c, 0xe1, 0xd8, 0x08, 0xfb, 0xe6, 0x77, 0x06, 0xef, 0xc1,
  0x18, 0x91, 0xb8, 0x9a, 0x65, 0x53, 0x10, 0x08, 0x0f, 0x84, 0x24, 0x1a,
  0xa5, 0x53, 0x94, 0xbc, 0xc5, 0x53, 0x30, 0x73, 0x63, 0xeb, 0x5e, 0xaf,
  0x1b, 0x1a, 0x32, 0x8d, 0xef, 0x6a, 0x8c, 0x9f, 0x15, 0xf9, 0x8e, 0x16,
  0x5e, 0x05, 0x03, 0x47, 0x16, 0xc8, 0x45, 0xe8, 0x45, 0xa9, 0x9c, 0x0b,
  0x21, 0x21, 0x96, 0xc7, 0x0b, 0x99, 0x41, 0x6d, 0xdc, 0x97, 0x73, 0x41,
  0x47, 0xfb, 0x7a, 0x16, 0x0f, 0x70, 0xa9, 0x6d, 0x16, 0x36, 0xa2, 0x64,
  0x70, 0xba, 0x3c, 0xd4, 0x0e, 0x59, 0x0f, 0xcc, 0x0e, 0x3e, 0x5d, 0x44,
  0x81, 0xc7, 0x1e, 0xea, 0xd0, 0x79, 0xfd, 0xf9, 0x25, 0x34, 0xc2, 0x2f,
  0xf0, 0x0f, 0xeb, 0xe3, 0xdf, 0x01, 0x2d, 0xad, 0xef, 0x51, 0xa0, 0xf0,
  0xa2, 0xb8, 0x72, 0xe9, 0x1e, 0x69, 0x05, 0x72, 0x75, 0xc8, 0x41, 0x9e,
  0x87, 0x7d, 0x86, 0xbb, 0xca, 0x70, 0x92, 0x45, 0x2c, 0xe9, 0xf6, 0xa0,
  0x47, 0xae, 0xf8, 0xed, 0xea, 0x6e, 0x62, 0xcf, 0x4c, 0x7e, 0xaf, 0x21,
  0x8e, 0xf0, 0x52, 0xc2, 0xeb, 0x9c, 0x89, 0x7b, 0xd4, 0x52, 0x18, 0x17,
  0x09, 0x71, 0x7b, 0xc4, 0xc2, 0x78, 0x69, 0x20, 0x8f, 0x8b, 0x72, 0xee,
  0x04, 0x29, 0x8c, 0x75, 0x8d, 0x57, 0xb1, 0xce, 0xbd, 0x0c, 0x2e, 0x55,
  0x2f, 0xed, 0xfd, 0xe2, 0xfb, 0xca, 0x72, 0xeb, 0x6e, 0xcc, 0x04, 0xd0,
  0xdc, 0xac, 0x9a, 0x31, 0xff, 0x6a, 0x14, 0x0d, 0x4e, 0x97, 0x87, 0xba,
  0xf8, 0x0f, 0xbe, 0xff, 0xba, 0xab, 0x8b, 0xef, 0x88, 0xf2, 0x07, 0x7d,
  0xe5, 0x78, 0xc8, 0xbb, 0x45, 0x97, 0x0e, 0xf9, 0xce, 0x4d, 0xce, 0x79,
  0xec, 0xf2, 0x69, 0x18, 0x17, 0xba, 0xc7, 0x08, 0xb2, 0x88, 0x29, 0xdd,
  0x1e, 0xf4, 0xc8, 0x15, 0xbf, 0x95, 0x88, 0xc0, 0x10, 0x5c, 0x48, 0xe2,
  0xc9, 0xcc, 0x2b, 0xb5, 0x03, 0x96, 0xba, 0x57, 0xfc, 0xf9, 0x81, 0xd9,
  0xaa, 0x40, 0x61, 0xe0, 0x7d, 0x86, 0xb6, 0xe3, 0x31, 0x35, 0x3c, 0x0f,
  0xf2, 0x32, 0x78, 0x06, 0x94, 0x55, 0x57, 0xbc, 0x1b, 0xb4, 0x60, 0x4e,
  0xbc, 0xa1, 0x5b, 0x3a, 0xc8, 0x5a, 0x07, 0x1e, 0x41, 0x8c, 0x57, 0xf5,
  0x82, 0xd7, 0x61, 0x63, 0x4f, 0x9a, 0x4f, 0x72, 0x70, 0x97, 0x02, 0x67,
  0x01, 0x21, 0x61, 0x4f, 0x7f, 0x4c, 0xe7, 0xa7, 0x48, 0xb8, 0xa7, 0x5d,
  0x72, 0x15, 0xec, 0xd8, 0x42, 0x5e, 0x24, 0x42, 0x95, 0x56, 0xbc, 0xff,
  0x6b, 0x1e, 0x45, 0x83, 0xd3, 0xe5, 0xa1, 0x2e, 0xfe, 0x0f, 0x10, 0xc2,
  0x4d, 0xea, 0xc6, 0x9f, 0x2d, 0x29, 0xee, 0xbc, 0x02, 0xdf, 0x42, 0x26,
  0xb8, 0x7e, 0x80, 0x82, 0x22, 0x04, 0xc3, 0xbc, 0x4b, 0x9f, 0x13, 0xfa,
  0x13, 0xcb, 0x7f, 0x06, 0xb7, 0x25, 0x34, 0x4f, 0xf6, 0xc0, 0xeb, 0xa2,
  0xc7, 0x75, 0xe9, 0x40, 0x0a, 0x92, 0xd0, 0x92, 0xd7, 0x01, 0x70, 0x6f,
  0x86, 0x07, 0xf1, 0x28, 0xb3, 0x43, 0x51, 0x91, 0xa2, 0x60, 0xaf, 0x58,
  0x0f, 0x15, 0x6b, 0x4d, 0x59, 0xc4, 0x94, 0x6e, 0x0f, 0x7a, 0xe4, 0x8a,
  0xdf, 0xe1, 0x12, 0xf5, 0x24, 0xf1, 0xe4, 0x06, 0x8f, 0x43, 0xdb, 0x28,
  0x62, 0x7f, 0xf3, 0x44, 0x1a, 0x26, 0x62, 0xe9, 0xab, 0xe2, 0x65, 0x81,
  0x09, 0x97, 0xc4, 0x03, 0xdc, 0x95, 0xd2, 0xfc, 0x65, 0x8a, 0x75, 0x0e,
  0x7a, 0xc4, 0x1b, 0xee, 0x2f, 0x78, 0x0b, 0x8b, 0xf7, 0x70, 0x7b, 0x6d,
  0x0f, 0x66, 0xb1, 0xa7, 0x5d, 0x22, 0x4f, 0x2a, 0x14, 0x2e, 0xff, 0x11,
  0x80, 0xf5, 0x8e, 0x8b, 0xcb, 0xd4, 0x32, 0x61, 0x78, 0x46, 0x22, 0xd0,
  0x13, 0x6e, 0xcc, 0x2d, 0x0f, 0x75, 0xf1, 0xe3, 0x81, 0xf4, 0x64, 0xf1,
  0x20, 0x57, 0xee, 0x4f, 0xb1, 0xf1, 0x7a, 0x99, 0xb8, 0xeb, 0x3a, 0x23,
  0x42, 0x2f, 0xf9, 0x01, 0xf0, 0x65, 0x06, 0x5b, 0x19, 0x0c, 0x61, 0x90,
  0xd7, 0xe3, 0x3e, 0x07, 0x88, 0x0b, 0x7d, 0xf9, 0x61, 0xf6, 0x06, 0x91,
  0x9a, 0xdc, 0xb2, 0xad, 0xa7, 0x23, 0x8b, 0x58, 0xd3, 0xad, 0xab, 0x47,
  0x6e, 0xf9, 0xed, 0xff, 0x19, 0x8b, 0xff, 0x67, 0x2c, 0xbe, 0x2c, 0xfc,
  0xe6, 0x0b, 0xd9, 0x97, 0x85, 0x2f, 0x0b, 0x5f, 0xc8, 0x7e, 0xf3, 0x65,
  0xe1, 0xb7, 0x54, 0x0a, 0x99, 0xf8, 0xff, 0xfb, 0x97, 0x2f, 0x8b, 0x18,
  0xb7, 0x7f, 0x01, 0x6c, 0xbb, 0xd7, 0x06, 0xa1, 0x47, 0x14, 0xbf, 0x00,
  0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_0_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0xb9, 0xf0, 0xdc, 0x11, 0x00, 0x00, 0x01,
  0x6a, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0xbd, 0x93, 0x4b, 0x2f, 0x03,
  0x51, 0x14, 0xc7, 0x2f, 0x15, 0xf1, 0xe8, 0x86, 0x44, 0x04, 0x51, 0xa5,
  0x0f, 0x89, 0x0a, 0x61, 0x27, 0x21, 0x51, 0xaf, 0x25, 0x1f, 0x81, 0xd8,
  0xe1, 0x2b, 0xb0, 0x10, 0x23, 0x6c, 0x24, 0xda, 0xfa, 0x14, 0xed, 0x4c,
  0x82, 0xe8, 0xc6, 0x92, 0x44, 0xc7, 0x47, 0xd1, 0x69, 0x47, 0xc2, 0xc2,
  0x8c, 0xcd, 0x75, 0xfe, 0x77, 0x66, 0x9c, 0x76, 0x4a, 0x62, 0xe5, 0x24,
  0xbf, 0xa4, 0xf9, 0x3f, 0x26, 0x77, 0xe6, 0x9e, 0x0a, 0xf1, 0x9f, 0x93,
  0x24, 0x0c, 0xe2, 0x35, 0x84, 0xe1, 0x7b, 0x4d, 0x93, 0x22, 0xec, 0xc4,
  0x90, 0x90, 0xfa, 0x91, 0x90, 0xb6, 0xe1, 0x81, 0xdf, 0xd0, 0xe0, 0xf9,
  0x99, 0xef, 0xa9, 0x24, 0x87, 0x85, 0xac, 0x53, 0x48, 0xde, 0x37, 0x03,
  0x0d, 0x1e, 0x32, 0x41, 0x38, 0x4b, 0xc8, 0xa7, 0x4b, 0x2f, 0x50, 0xd3,
  0x85, 0x9c, 0x8e, 0x0b, 0x99, 0x19, 0x13, 0xb2, 0x5a, 0xf4, 0x34, 0x78,
  0xc8, 0xf8, 0x59, 0x71, 0xb5, 0x3c, 0xc3, 0x4f, 0xd4, 0x76, 0x94, 0x51,
  0x27, 0xac, 0x93, 0x6d, 0xd6, 0x91, 0x41, 0x16, 0x85, 0xe7, 0xc2, 0x01,
  0x1b, 0xab, 0x73, 0xca, 0x38, 0x25, 0xb4, 0xcd, 0x05, 0xd6, 0x91, 0x41,
  0x16, 0x85, 0x9a, 0x99, 0x67, 0x63, 0x74, 0x40, 0x19, 0x6b, 0xc4, 0x16,
  0xce, 0x1e, 0xe8, 0xc8, 0x20, 0x8b, 0xc2, 0xa7, 0x55, 0x62, 0xa3, 0xbb,
  0x53, 0x19, 0x31, 0x7c, 0x95, 0xbe, 0x28, 0xeb, 0xc8, 0x90, 0xe6, 0xaa,
  0x82, 0x5b, 0x66, 0xa3, 0xcd, 0x7b, 0xb9, 0x1e, 0xa2, 0xbf, 0x23, 0xc2,
  0xba, 0x53, 0x6e, 0x28, 0x38, 0x3f, 0x17, 0xa2, 0x91, 0x76, 0xd6, 0x3f,
  0xee, 0xb8, 0xe0, 0x06, 0x9f, 0x2f, 0x74, 0xa4, 0xf1, 0xde, 0x2e, 0xd6,
  0x5f, 0x8a, 0x4a, 0x77, 0x50, 0xb0, 0x2a, 0xb9, 0x96, 0x97, 0x5e, 0x21,
  0x36, 0xe2, 0x83, 0xac, 0x23, 0x43, 0x5a, 0x15, 0x05, 0x33, 0xb7, 0xc7,
  0x46, 0x76, 0x56, 0x19, 0x1a, 0x71, 0xbe, 0x3e, 0xcf, 0x7a, 0x7e, 0x5f,
  0xe9, 0x26, 0x0a, 0xf9, 0xc5, 0x0c, 0x1b, 0xb8, 0x2c, 0xff, 0xe2, 0xec,
  0xb3, 0xdd, 0x96, 0x8b, 0x2b, 0xa0, 0xb0, 0x84, 0x6b, 0x7f, 0xb8, 0xe0,
  0xd5, 0x98, 0x8a, 0x79, 0xeb, 0x11, 0xec, 0x56, 0x78, 0x35, 0x30, 0x8f,
  0xe9, 0x91, 0xbf, 0x2f, 0x1f, 0x66, 0x12, 0x47, 0x48, 0x51, 0xe9, 0xe6,
  0x58, 0xc8, 0xb7, 0x6b, 0x6f, 0xbd, 0x4b, 0x87, 0x42, 0x4e, 0xfc, 0xb2,
  0xde, 0x98, 0x34, 0x71, 0x4b, 0xbc, 0x37, 0x80, 0x3f, 0x90, 0x4e, 0x24,
  0x82, 0xd0, 0x17, 0x7d, 0xca, 0x43, 0xd6, 0xce, 0xe7, 0x04, 0x20, 0x00,
  0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_1_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0xb9, 0xf0, 0xdc, 0x11, 0x00, 0x00, 0x00,
  0x7c, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0x63, 0x60, 0xa0, 0x02, 0xe0,
  0x03, 0x62, 0x3f, 0x24, 0x8c, 0x01, 0x58, 0x81, 0xd8, 0x0e, 0x88, 0x9b,
  0x80, 0xf8, 0x18, 0x10, 0xff, 0xe6, 0xe5, 0x64, 0xf8, 0xef, 0x6b, 0xc1,
  0xf0, 0x1f, 0xc8, 0xfe, 0x8f, 0x4d, 0xc3, 0x17, 0x16, 0x66, 0x86, 0xff,
  0xb6, 0x3a, 0x0c, 0xff, 0x1b, 0xe3, 0x18, 0xfe, 0x1f, 0xed, 0x67, 0xf8,
  0xff, 0x6b, 0x1b, 0xc3, 0xff, 0xff, 0xbb, 0xf0, 0x68, 0xf8, 0xbc, 0x11,
  0xa2, 0x00, 0x1d, 0xe3, 0xd4, 0xf0, 0x7a, 0x35, 0xc3, 0xff, 0x95, 0xd5,
  0x0c, 0xff, 0x53, 0x3d, 0x89, 0xd3, 0xf0, 0x06, 0x09, 0x13, 0xa5, 0x81,
  0x11, 0x09, 0x13, 0xa5, 0x01, 0x19, 0x8c, 0x6a, 0x18, 0x38, 0x0d, 0xff,
  0x91, 0x31, 0x16, 0x0d, 0xe8, 0x18, 0x7b, 0xc2, 0xc3, 0x97, 0x18, 0x49,
  0xd7, 0x40, 0x0a, 0x06, 0x00, 0x09, 0xe6, 0xf7, 0x70, 0x7c, 0x8a, 0x96,
  0x20, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60,
  0x82
};
unsigned char devdigit_2_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0xb9, 0xf0, 0xdc, 0x11, 0x00, 0x00, 0x01,
  0x3d, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0xbd, 0x92, 0x41, 0x28, 0x83,
  0x61, 0x1c, 0x87, 0x9f, 0x19, 0xdb, 0x6c, 0x0d, 0x6d, 0x71, 0x5b, 0x94,
  0x94, 0xe3, 0xc4, 0xcd, 0x8d, 0x8b, 0xab, 0xe5, 0xea, 0x82, 0x93, 0xdb,
  0x58, 0x72, 0xe3, 0x36, 0x2e, 0x5a, 0x24, 0x07, 0x94, 0x11, 0x45, 0x6d,
  0x72, 0x21, 0x8b, 0x93, 0x35, 0x17, 0xca, 0x4e, 0x5c, 0x38, 0x9b, 0xc3,
  0xa6, 0x38, 0x99, 0xfa, 0x39, 0x7c, 0xdb, 0xbe, 0x8f, 0x6c, 0x72, 0xd9,
  0xbf, 0x9e, 0x7a, 0x0f, 0xbf, 0xa7, 0xfe, 0xef, 0xef, 0x7d, 0xa1, 0x1e,
  0xb3, 0x06, 0xa4, 0x80, 0x27, 0xa0, 0x00, 0x14, 0x2d, 0xbc, 0x02, 0xd7,
  0xc0, 0x0c, 0xe0, 0x2a, 0x0b, 0x5a, 0x9d, 0x46, 0xe7, 0x51, 0xf4, 0x18,
  0x47, 0xf9, 0x04, 0xfa, 0x38, 0x45, 0x85, 0x24, 0xca, 0xc4, 0x50, 0x38,
  0x84, 0x9c, 0x4d, 0x08, 0xc8, 0x02, 0x7e, 0x00, 0x29, 0x55, 0x9b, 0xbb,
  0x0d, 0xe4, 0xf3, 0x22, 0x60, 0x0b, 0x40, 0xbb, 0x73, 0x68, 0x72, 0x04,
  0x05, 0xbb, 0x51, 0x8b, 0x1b, 0x39, 0x1a, 0x8d, 0xf3, 0xd5, 0x8a, 0x29,
  0x6d, 0x86, 0x11, 0xf0, 0x02, 0xb0, 0x67, 0x61, 0x0a, 0xe8, 0x2b, 0x91,
  0xee, 0x0d, 0x98, 0x42, 0xee, 0x08, 0x01, 0xef, 0xb5, 0xca, 0x18, 0x70,
  0x39, 0x4c, 0xe1, 0xed, 0xa4, 0xb6, 0x60, 0x07, 0x2e, 0xfb, 0x7b, 0x4c,
  0x21, 0x13, 0xab, 0x2e, 0xd8, 0x81, 0x83, 0x06, 0x1b, 0xba, 0x58, 0x36,
  0x85, 0xd1, 0x41, 0x54, 0xaa, 0xf8, 0xdb, 0x34, 0x03, 0xc7, 0x0d, 0x36,
  0xb4, 0x3f, 0x6f, 0x86, 0xa3, 0x13, 0x08, 0x10, 0x10, 0xb2, 0x86, 0xdb,
  0x80, 0xb4, 0xcb, 0x81, 0x92, 0x0b, 0x46, 0xb0, 0x78, 0x86, 0x66, 0xc7,
  0x2a, 0xe1, 0x25, 0x6b, 0xd8, 0x0f, 0x64, 0x5b, 0x3d, 0x66, 0x95, 0xcf,
  0x87, 0x68, 0x28, 0x88, 0x80, 0x4f, 0x20, 0x62, 0x0d, 0x7b, 0x80, 0x5b,
  0x9f, 0xd7, 0x78, 0x20, 0xa5, 0xd0, 0xfd, 0x36, 0xea, 0xec, 0x40, 0x40,
  0x0e, 0x18, 0xfe, 0xb9, 0x77, 0xdc, 0xed, 0x44, 0x37, 0xeb, 0x46, 0x38,
  0x9f, 0x40, 0x81, 0x76, 0x04, 0x3c, 0x00, 0x5d, 0xbf, 0xb5, 0xa2, 0x9d,
  0x88, 0x79, 0xc1, 0xc5, 0xf1, 0xca, 0xce, 0xd5, 0xf8, 0xfb, 0x2f, 0x95,
  0xa9, 0xa3, 0xf0, 0x1f, 0xbe, 0x00, 0xf0, 0x04, 0x2d, 0x7b, 0x94, 0x44,
  0xbf, 0x7c, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
  0x60, 0x82
};
unsigned char devdigit_3_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0xb9, 0xf0, 0xdc, 0x11, 0x00, 0x00, 0x01,
  0x86, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0xbd, 0xd3, 0x3f, 0x6c, 0xcd,
  0x61, 0x18, 0xc5, 0xf1, 0x0f, 0x8d, 0xb8, 0xe1, 0x2e, 0x82, 0x89, 0x4a,
  0x34, 0x91, 0x30, 0xb4, 0x1d, 0x88, 0xb1, 0xc5, 0x42, 0x18, 0x58, 0x14,
  0xab, 0x36, 0x18, 0xea, 0x4f, 0x24, 0x88, 0xea, 0x24, 0xa6, 0x62, 0x11,
  0x24, 0xe8, 0x4d, 0x89, 0x26, 0x1d, 0x24, 0x08, 0x57, 0x35, 0x1d, 0x74,
  0x6e, 0x99, 0x48, 0xb4, 0x49, 0x5b, 0x1b, 0xab, 0x56, 0x42, 0xab, 0xd2,
  0x3e, 0x86, 0xdf, 0x75, 0x7f, 0xbf, 0x5b, 0x6d, 0x6d, 0xde, 0xe4, 0x6c,
  0xcf, 0xf7, 0x7d, 0x4f, 0xce, 0x73, 0x5e, 0xfe, 0xd7, 0x19, 0xc0, 0x38,
  0x26, 0xf1, 0x2b, 0xa3, 0x69, 0x8c, 0xa1, 0x80, 0x6d, 0x59, 0x20, 0xde,
  0x74, 0x88, 0xb1, 0x87, 0x62, 0xe2, 0x99, 0x98, 0xe9, 0x15, 0x53, 0x45,
  0x31, 0xda, 0x25, 0x3a, 0xcf, 0x8b, 0xad, 0xd5, 0x02, 0x3f, 0xd0, 0x58,
  0x06, 0xa2, 0x7f, 0x71, 0x7d, 0x7f, 0x21, 0x1a, 0x6a, 0x05, 0xde, 0x95,
  0x81, 0xe6, 0x7d, 0xa2, 0x76, 0xb3, 0x58, 0x93, 0x17, 0x2b, 0xaa, 0x92,
  0x5b, 0x7b, 0xaf, 0xa5, 0xd0, 0xdb, 0xdb, 0xa2, 0x64, 0x11, 0xb4, 0x64,
  0x54, 0x57, 0xf2, 0xfb, 0x7a, 0xe3, 0xba, 0x14, 0x98, 0x2a, 0x56, 0x02,
  0x0b, 0x9d, 0xb6, 0x7c, 0x2e, 0x05, 0x86, 0x0b, 0x7f, 0x03, 0xcd, 0x38,
  0x8b, 0xeb, 0x18, 0x42, 0x5c, 0x3e, 0x9a, 0x0c, 0xcf, 0xf6, 0x89, 0xa6,
  0x06, 0x81, 0x91, 0x8a, 0xa4, 0x8e, 0xef, 0x15, 0x67, 0x0e, 0x89, 0x8e,
  0x16, 0x31, 0x78, 0x2b, 0x19, 0x1e, 0x29, 0x88, 0xfd, 0x3b, 0x05, 0xe6,
  0x70, 0xa4, 0x02, 0x98, 0x9f, 0xce, 0x93, 0x76, 0xb1, 0x61, 0xad, 0xc0,
  0x0c, 0xda, 0xe7, 0x7b, 0x8e, 0x1b, 0x27, 0xc4, 0x9d, 0x56, 0xf1, 0xf2,
  0xaa, 0xf8, 0xfa, 0x34, 0x81, 0x7e, 0xbe, 0x12, 0x57, 0x8e, 0x09, 0x04,
  0x4e, 0x65, 0x81, 0x9b, 0xb8, 0x8b, 0x22, 0x26, 0x56, 0xe7, 0x92, 0x65,
  0xfe, 0x79, 0xed, 0xe4, 0x01, 0x81, 0xe1, 0xc5, 0x12, 0xca, 0x63, 0xa0,
  0xbe, 0x26, 0x05, 0x3e, 0x76, 0xfe, 0x3b, 0xd6, 0x1d, 0xab, 0x56, 0x2e,
  0xbc, 0x87, 0xd3, 0x19, 0xed, 0xc1, 0x26, 0xec, 0xc2, 0x87, 0xed, 0x5b,
  0x52, 0x60, 0xb4, 0x2b, 0x05, 0xa2, 0xf5, 0xa0, 0xd8, 0x5d, 0x2f, 0xaa,
  0xd7, 0x27, 0xb5, 0xc8, 0xe7, 0x44, 0x63, 0x9d, 0x78, 0x7f, 0x2f, 0x05,
  0x2e, 0x1c, 0x16, 0xa5, 0xe6, 0x2e, 0x5d, 0xbc, 0xe8, 0x17, 0xf7, 0xcf,
  0x89, 0xe5, 0xcb, 0x04, 0x2e, 0x42, 0x7c, 0xee, 0x11, 0x93, 0xcf, 0x93,
  0x08, 0x67, 0xfb, 0x12, 0xbf, 0xe3, 0x8f, 0xc4, 0xe3, 0x4b, 0xe5, 0x96,
  0x06, 0x1e, 0xa0, 0x0a, 0xbe, 0xe0, 0x5b, 0x69, 0x39, 0x73, 0x19, 0x4d,
  0xe3, 0x13, 0xba, 0xb3, 0xff, 0xe0, 0x37, 0x1c, 0x29, 0x1b, 0xc9, 0x07,
  0xdf, 0x9a, 0x4d, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae,
  0x42, 0x60, 0x82
};
unsigned char devdigit_4_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x56, 0x32, 0xb7, 0x2f, 0x00, 0x00, 0x00,
  0xc6, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0x63, 0x60, 0x18, 0x0c, 0xa0,
  0x02, 0x88, 0xff, 0x63, 0xc1, 0x38, 0x81, 0x1e, 0x10, 0xff, 0x2c, 0x0f,
  0x67, 0xf8, 0xff, 0x7f, 0x17, 0x02, 0xe3, 0xd3, 0xc4, 0x06, 0xc4, 0x17,
  0x75, 0x15, 0x19, 0xfe, 0xff, 0xd8, 0x4a, 0xbc, 0xa6, 0x0e, 0x56, 0x66,
  0x86, 0xff, 0x17, 0xa6, 0xa3, 0x6a, 0xc0, 0xa7, 0xc9, 0x0a, 0x88, 0xff,
  0xb6, 0x27, 0x41, 0x14, 0x5d, 0x9e, 0x45, 0x58, 0x13, 0x37, 0x10, 0xdf,
  0xb1, 0xd4, 0x64, 0xf8, 0xff, 0x67, 0x07, 0xc3, 0xff, 0xdf, 0xdb, 0x19,
  0xfe, 0x9b, 0xaa, 0x11, 0xd6, 0x34, 0x83, 0x8b, 0x9d, 0xe1, 0xff, 0xed,
  0xf9, 0x10, 0x05, 0x5d, 0x29, 0x10, 0x45, 0xf8, 0x34, 0x79, 0x80, 0x04,
  0xa6, 0xe7, 0x41, 0x24, 0x6f, 0xce, 0x63, 0xf8, 0xcf, 0xc1, 0x86, 0x5f,
  0x93, 0x10, 0x10, 0x3f, 0x75, 0x37, 0x81, 0x48, 0xfc, 0x05, 0x3a, 0xcd,
  0x5a, 0x1b, 0x2c, 0x79, 0x0b, 0x9f, 0xa6, 0x15, 0x82, 0x3c, 0x0c, 0xff,
  0x9f, 0x2c, 0x83, 0x48, 0x4c, 0xca, 0x02, 0x4b, 0xfc, 0x03, 0x62, 0x1b,
  0x7c, 0x9a, 0xfe, 0x2f, 0xaf, 0x82, 0x08, 0xde, 0x5b, 0xc4, 0xf0, 0x1f,
  0xe4, 0x2f, 0xe4, 0x14, 0x80, 0x45, 0x13, 0x58, 0x23, 0x46, 0x7c, 0xe0,
  0xc3, 0x94, 0x69, 0xc2, 0x87, 0x71, 0x39, 0x0f, 0x1f, 0x20, 0x3a, 0xed,
  0x0d, 0x90, 0x26, 0x6c, 0x99, 0x10, 0x00, 0x10, 0x35, 0x2e, 0x1a, 0x0e,
  0xfb, 0x7b, 0x23, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae,
  0x42, 0x60, 0x82
};
unsigned char devdigit_5_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0b, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x5b, 0x2c, 0xc7, 0x68, 0x00, 0x00, 0x01,
  0x0a, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0x63, 0x60, 0xa0, 0x25, 0xf8,
  0x4f, 0x02, 0x66, 0xf8, 0xff, 0x7f, 0x17, 0x61, 0x4c, 0x47, 0xc5, 0x15,
  0xe1, 0x24, 0xb8, 0x39, 0xcb, 0x17, 0x2c, 0x50, 0x89, 0x37, 0x34, 0x60,
  0x8a, 0x63, 0x5d, 0xc0, 0x8a, 0x8f, 0x00, 0xf1, 0x74, 0x20, 0x2e, 0x04,
  0x62, 0x3d, 0x9c, 0x8a, 0x0f, 0xf7, 0x31, 0xfc, 0x9f, 0x96, 0xcb, 0xf0,
  0xbf, 0x20, 0x90, 0xe1, 0xbf, 0xae, 0x22, 0xdc, 0xea, 0xc3, 0x40, 0xac,
  0x82, 0xa1, 0x18, 0x1d, 0x1f, 0xea, 0x65, 0xf8, 0xaf, 0x2c, 0x09, 0xd6,
  0xf0, 0x16, 0x88, 0x15, 0xc1, 0x8a, 0xd5, 0xa4, 0x19, 0xfe, 0x33, 0x33,
  0x31, 0xfc, 0x17, 0xe0, 0x66, 0xf8, 0x6f, 0xa7, 0xcb, 0xf0, 0x7f, 0x41,
  0x09, 0x42, 0xc3, 0x9b, 0x35, 0x0c, 0xff, 0x15, 0xc4, 0xc1, 0x1a, 0x96,
  0x81, 0x14, 0xab, 0x23, 0x61, 0x7b, 0x20, 0x5e, 0x08, 0x32, 0xa0, 0x35,
  0x11, 0xa1, 0x61, 0x69, 0x05, 0x58, 0xf1, 0x2b, 0x5c, 0x9e, 0x6e, 0x93,
  0x10, 0x44, 0x28, 0x7e, 0xb9, 0x0a, 0xac, 0xf8, 0x1b, 0x2e, 0xc5, 0x41,
  0x3c, 0x1c, 0x08, 0xc5, 0x5f, 0x37, 0x21, 0x14, 0x5b, 0x21, 0x61, 0x49,
  0x20, 0x0e, 0x03, 0x59, 0x19, 0x68, 0x8d, 0x50, 0x7c, 0x7a, 0x0a, 0x42,
  0xf1, 0x7f, 0x4b, 0x4d, 0x86, 0xff, 0x20, 0x6b, 0xd9, 0x58, 0x18, 0xfe,
  0xf3, 0x03, 0x3d, 0x19, 0x6a, 0x07, 0xb1, 0x1a, 0x2d, 0xfc, 0xcf, 0x10,
  0x4c, 0x1b, 0xed, 0x49, 0xf0, 0xf0, 0x8e, 0x03, 0x2b, 0xfe, 0xb4, 0x81,
  0xe1, 0xff, 0x8f, 0xad, 0x0c, 0xff, 0xff, 0xee, 0x60, 0xf8, 0xff, 0x6b,
  0x1b, 0xc3, 0xff, 0xc7, 0x4b, 0x19, 0xfe, 0xaf, 0xa8, 0x62, 0xf8, 0x6f,
  0xa3, 0x0d, 0x57, 0xd8, 0x01, 0xf3, 0xcc, 0x67, 0x20, 0xfe, 0x09, 0xc4,
  0xff, 0x90, 0xf0, 0x6f, 0x20, 0x7e, 0x02, 0xc4, 0x2b, 0x81, 0xd8, 0x16,
  0xa6, 0x10, 0x00, 0x2a, 0x24, 0x25, 0x9c, 0x2b, 0xd4, 0x93, 0xd9, 0x00,
  0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_6_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x56, 0x32, 0xb7, 0x2f, 0x00, 0x00, 0x01,
  0xbc, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xc5, 0x92, 0x49, 0x28, 0x85,
  0x51, 0x14, 0xc7, 0x8f, 0x12, 0x9e, 0xe7, 0x49, 0xc6, 0x32, 0x94, 0x6c,
  0x50, 0x86, 0x8d, 0xc4, 0x82, 0x67, 0x28, 0x19, 0x32, 0x2c, 0xcc, 0x91,
  0x9e, 0x85, 0x85, 0x05, 0x29, 0x1b, 0x96, 0xa4, 0x6c, 0x58, 0xb0, 0x30,
  0x3d, 0x91, 0x32, 0x96, 0xc8, 0x10, 0x61, 0x63, 0xd8, 0x93, 0x79, 0x8c,
  0xf2, 0x64, 0x28, 0xe2, 0x65, 0xf6, 0x38, 0xce, 0xbd, 0xef, 0xfb, 0xde,
  0xfd, 0x9e, 0x69, 0xeb, 0xd6, 0x6f, 0xf5, 0xff, 0x7e, 0xdf, 0x3d, 0xe7,
  0xdc, 0x03, 0xf0, 0x5f, 0x27, 0x88, 0x68, 0x27, 0x8e, 0x88, 0x67, 0xc2,
  0xa4, 0xe0, 0x81, 0xb8, 0xfc, 0x2a, 0x94, 0x12, 0x2f, 0x81, 0xbe, 0x80,
  0x6d, 0x15, 0x80, 0x87, 0xbd, 0x80, 0x4f, 0x53, 0x80, 0x6f, 0x33, 0x80,
  0xf7, 0x13, 0x80, 0x17, 0xc3, 0x80, 0x94, 0xa3, 0x52, 0x48, 0x23, 0x3e,
  0x74, 0x49, 0x80, 0xcf, 0xd3, 0x80, 0x38, 0xf7, 0x33, 0x4a, 0xc9, 0x9e,
  0x30, 0xa4, 0x46, 0x02, 0xbe, 0xcf, 0x9a, 0x43, 0xc3, 0x00, 0x60, 0x66,
  0x34, 0xa0, 0xda, 0x01, 0x50, 0x65, 0x07, 0x18, 0xe4, 0x07, 0x98, 0x1b,
  0x6b, 0x2d, 0x15, 0xda, 0xd9, 0x02, 0x9e, 0xf6, 0x9b, 0x85, 0x17, 0xba,
  0x29, 0xc4, 0x9f, 0x87, 0x67, 0x44, 0x16, 0x11, 0x4c, 0xe4, 0x29, 0xe0,
  0x67, 0xb0, 0x20, 0x5e, 0x94, 0x30, 0x54, 0xcb, 0x85, 0x57, 0x22, 0xf4,
  0xaf, 0x89, 0xed, 0x0d, 0xd4, 0x08, 0xa9, 0x2c, 0x95, 0x4b, 0x47, 0x92,
  0x28, 0xc3, 0x6e, 0xed, 0x20, 0xbc, 0x64, 0xe9, 0x6e, 0xb7, 0x5b, 0x48,
  0x39, 0x54, 0x7b, 0x83, 0xce, 0x3c, 0x3d, 0x56, 0x2a, 0xeb, 0xaf, 0xbd,
  0x12, 0xd0, 0xd3, 0x85, 0xff, 0xec, 0x84, 0xf0, 0x60, 0x92, 0xe9, 0x76,
  0x4c, 0x48, 0xc6, 0xf1, 0x9f, 0x27, 0x77, 0xdc, 0x07, 0xe8, 0xee, 0xcc,
  0xc5, 0x56, 0x2e, 0xb1, 0xb7, 0x90, 0xc3, 0xcb, 0x11, 0xc0, 0xf4, 0x28,
  0x40, 0x27, 0x9a, 0x5c, 0x78, 0x00, 0xe0, 0x6a, 0x9b, 0xc8, 0x5a, 0xca,
  0x2d, 0xb7, 0x81, 0xe9, 0x4e, 0xf1, 0xf7, 0x3c, 0x2d, 0x0f, 0xae, 0x88,
  0x0c, 0x62, 0x4d, 0x1b, 0x66, 0x7d, 0x9b, 0xd4, 0x23, 0x18, 0x37, 0x3b,
  0x45, 0xe0, 0xa2, 0xe6, 0x41, 0xbe, 0xd4, 0x6f, 0x9c, 0x46, 0x25, 0x32,
  0xd6, 0xa3, 0x2c, 0x6d, 0xf5, 0x54, 0x8b, 0xc0, 0x55, 0x63, 0x25, 0x25,
  0x38, 0x3b, 0x8a, 0xec, 0x7a, 0x54, 0x48, 0xbd, 0xc9, 0x11, 0xdf, 0xca,
  0xbb, 0x90, 0x56, 0x6b, 0x23, 0x3e, 0x5c, 0x64, 0xf3, 0x8d, 0x3c, 0xbb,
  0x61, 0x52, 0x0a, 0x5b, 0x8f, 0xc5, 0x26, 0x73, 0x70, 0x3e, 0x04, 0xc8,
  0x56, 0x4a, 0x2d, 0x0d, 0x62, 0xbd, 0x43, 0x48, 0xd9, 0x31, 0x5c, 0x5a,
  0x60, 0x92, 0x0d, 0xb1, 0xe4, 0xed, 0x06, 0xb8, 0xdf, 0xf3, 0xfb, 0xb2,
  0x76, 0x55, 0x59, 0x76, 0x2f, 0x47, 0x7e, 0x60, 0x1f, 0xe2, 0x80, 0x8d,
  0xb9, 0xae, 0x04, 0x70, 0x5b, 0x0f, 0xf8, 0x38, 0x09, 0xc8, 0xa6, 0xba,
  0xdc, 0x0c, 0x58, 0x94, 0x68, 0x11, 0xf4, 0x5f, 0xd7, 0x49, 0x43, 0xd4,
  0x13, 0x3b, 0xc4, 0x93, 0x02, 0x23, 0xb1, 0x42, 0x14, 0xcb, 0x1f, 0x7e,
  0x02, 0xc8, 0xc9, 0x55, 0xb9, 0xda, 0x16, 0x80, 0x07, 0x00, 0x00, 0x00,
  0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_7_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0xb9, 0xf0, 0xdc, 0x11, 0x00, 0x00, 0x00,
  0xfc, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0x63, 0x60, 0xa0, 0x07, 0xf8,
  0x4f, 0x22, 0x66, 0xf8, 0xff, 0x7f, 0x17, 0x71, 0x98, 0x8e, 0x1a, 0x70,
  0x61, 0x76, 0x56, 0x86, 0xff, 0xb7, 0xe6, 0x43, 0x14, 0x2f, 0xab, 0x44,
  0x68, 0xc0, 0x06, 0x74, 0x80, 0xf8, 0x57, 0x6b, 0x22, 0x44, 0xf1, 0xe3,
  0xa5, 0x0c, 0xff, 0x05, 0xb8, 0xc1, 0x8a, 0x97, 0x63, 0x53, 0xcc, 0x08,
  0xc4, 0xc7, 0xb4, 0xe5, 0x19, 0xfe, 0xff, 0xdc, 0x0a, 0xd1, 0xe0, 0x63,
  0x0e, 0x56, 0xfc, 0x04, 0x88, 0x05, 0xb1, 0x69, 0xc8, 0x00, 0x59, 0x7d,
  0xb4, 0x1f, 0xa2, 0x78, 0x4d, 0x2d, 0xdc, 0x29, 0xbe, 0xd8, 0x14, 0x8b,
  0x03, 0xf1, 0xfb, 0x74, 0x6f, 0x88, 0xe2, 0xef, 0x5b, 0x18, 0xfe, 0xcb,
  0x8b, 0x81, 0x15, 0xaf, 0xc5, 0xe5, 0xf6, 0xf9, 0x62, 0x02, 0x0c, 0xff,
  0xdf, 0xad, 0x85, 0x68, 0xe8, 0x4a, 0x01, 0x2b, 0xfe, 0x01, 0xc4, 0x0a,
  0xd8, 0x14, 0x9b, 0x00, 0xf1, 0xbf, 0x79, 0xc5, 0x10, 0xc5, 0x5f, 0x37,
  0x31, 0xfc, 0x17, 0xe5, 0x07, 0x6b, 0xe8, 0xc6, 0x65, 0xfa, 0x7e, 0x63,
  0x55, 0x86, 0xff, 0x7f, 0x77, 0x40, 0x34, 0x4c, 0xcf, 0x03, 0x2b, 0xfe,
  0x06, 0xc4, 0x62, 0xd8, 0x14, 0xdb, 0x82, 0x3c, 0xb6, 0xaf, 0x0b, 0x11,
  0x49, 0xfa, 0x4a, 0x60, 0x0d, 0x33, 0x70, 0x99, 0xbe, 0xd4, 0x46, 0x1b,
  0xa1, 0xf8, 0xc6, 0x5c, 0x78, 0xc8, 0x18, 0x60, 0x53, 0xcc, 0x06, 0xc4,
  0xdf, 0x97, 0x94, 0x23, 0x34, 0xf4, 0x67, 0x80, 0x15, 0xdf, 0xc4, 0x65,
  0xba, 0x05, 0x2b, 0x33, 0xc3, 0xff, 0x6f, 0x9b, 0x11, 0x1a, 0x22, 0x1d,
  0xc1, 0x1a, 0x26, 0xe0, 0xd4, 0x60, 0xae, 0x81, 0x9a, 0xc8, 0x2c, 0x34,
  0xc1, 0x1a, 0xa2, 0x70, 0x6a, 0xc0, 0x91, 0xf8, 0x2c, 0xb1, 0x29, 0x06,
  0x00, 0xb2, 0xca, 0xf8, 0x55, 0x80, 0x80, 0x9f, 0xd0, 0x00, 0x00, 0x00,
  0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_8_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x56, 0x32, 0xb7, 0x2f, 0x00, 0x00, 0x01,
  0xbf, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xc5, 0x92, 0x49, 0x28, 0x46,
  0x51, 0x14, 0xc7, 0x8f, 0xf1, 0x33, 0xa5, 0x44, 0x28, 0x32, 0x2c, 0x44,
  0x08, 0x65, 0xdc, 0xd8, 0x48, 0xf8, 0xac, 0x08, 0xa5, 0x88, 0x95, 0xad,
  0x59, 0x22, 0x25, 0xd6, 0xc6, 0x52, 0xca, 0x14, 0x32, 0x94, 0x21, 0xb3,
  0x64, 0x65, 0xa6, 0x28, 0x0b, 0x32, 0x6c, 0xc8, 0x9c, 0x05, 0x42, 0xbe,
  0xcf, 0x7c, 0x9c, 0x7b, 0x5f, 0x9f, 0xf3, 0x78, 0xf6, 0x5e, 0xfd, 0x16,
  0xef, 0xfe, 0xff, 0xbf, 0x37, 0x9c, 0x7b, 0x01, 0xfe, 0xe3, 0x0a, 0x22,
  0xfa, 0x89, 0x0b, 0xe2, 0x55, 0xc5, 0x29, 0x31, 0x49, 0xc4, 0xfc, 0x16,
  0xa2, 0x09, 0x43, 0xa0, 0x17, 0x60, 0x5f, 0x39, 0xe0, 0xf9, 0x00, 0xe0,
  0xcb, 0x0c, 0xe0, 0x49, 0x1f, 0xe0, 0x44, 0x0d, 0x60, 0x74, 0x00, 0x20,
  0xe5, 0x9f, 0x44, 0x86, 0x5a, 0x5a, 0x8c, 0xf2, 0x07, 0x7c, 0x9a, 0x04,
  0xc4, 0x79, 0x2d, 0x1f, 0x73, 0x80, 0xe9, 0xb1, 0x52, 0x3c, 0x54, 0x4b,
  0xc6, 0x85, 0x3a, 0x2e, 0xe5, 0xe9, 0x01, 0x6d, 0xad, 0x01, 0x4b, 0xd2,
  0x79, 0xed, 0xa0, 0x53, 0x4a, 0x86, 0x1f, 0x92, 0x61, 0x8a, 0x0b, 0x3a,
  0x2b, 0x59, 0x28, 0xb5, 0xd3, 0xf1, 0x9a, 0xf8, 0x0a, 0x8d, 0x74, 0x3b,
  0xca, 0x85, 0xb8, 0x30, 0x59, 0x38, 0x76, 0x73, 0xe2, 0xb5, 0xf5, 0x66,
  0xad, 0x74, 0x37, 0x5c, 0xc5, 0x85, 0xa3, 0x5e, 0x40, 0x0f, 0x67, 0xc0,
  0xda, 0x5c, 0xe5, 0xfe, 0x9d, 0xfe, 0x29, 0x21, 0x5c, 0x4a, 0x1b, 0x6a,
  0x69, 0xc4, 0xd3, 0x05, 0xf0, 0xac, 0x9f, 0xc5, 0xeb, 0x21, 0x65, 0x00,
  0xc6, 0x69, 0xc0, 0x9c, 0x78, 0x29, 0x7c, 0x10, 0x89, 0x6a, 0xa9, 0x44,
  0x8c, 0x34, 0x3f, 0x45, 0x3b, 0xb9, 0xed, 0x56, 0x40, 0xb1, 0x15, 0x94,
  0xbf, 0x10, 0x05, 0x26, 0x21, 0x99, 0xc0, 0xe2, 0x34, 0xe5, 0xc9, 0xa2,
  0x38, 0x50, 0x01, 0xa8, 0x1e, 0xcc, 0x33, 0xed, 0x99, 0x78, 0xa0, 0xe8,
  0x11, 0xd9, 0x42, 0x5a, 0xd1, 0x47, 0x72, 0xa1, 0xb3, 0x58, 0x09, 0xfd,
  0x3c, 0x00, 0xd7, 0x9a, 0x7e, 0xbe, 0x35, 0x2b, 0x4e, 0x66, 0xbb, 0x42,
  0x7a, 0x58, 0x6e, 0xe0, 0x20, 0xc8, 0x5b, 0x06, 0x5d, 0xc4, 0xba, 0x85,
  0x39, 0x60, 0x77, 0x29, 0x67, 0x3b, 0x6d, 0x32, 0x33, 0x4a, 0xe9, 0x7e,
  0x9c, 0x03, 0x6b, 0x4b, 0x19, 0x04, 0x13, 0x96, 0x44, 0x8f, 0x8b, 0x23,
  0x67, 0xe2, 0x93, 0xbf, 0xa5, 0x9b, 0x51, 0xcd, 0x9b, 0xd6, 0x88, 0x50,
  0x62, 0xd9, 0xdb, 0x95, 0xb3, 0xbd, 0x0e, 0x96, 0x6e, 0x7b, 0xca, 0x38,
  0x58, 0x6d, 0x04, 0x0c, 0xf1, 0x55, 0x4e, 0x45, 0xb0, 0x0f, 0xe0, 0x52,
  0x3d, 0x67, 0x85, 0xa9, 0x52, 0xda, 0x17, 0x52, 0xaf, 0xd8, 0x79, 0x71,
  0xb6, 0xfe, 0x3a, 0xac, 0x26, 0xda, 0x8b, 0x00, 0xcd, 0x94, 0xe9, 0x15,
  0x09, 0xc9, 0x5d, 0x9c, 0x5e, 0x7b, 0x1b, 0xc0, 0x8a, 0x4c, 0xc0, 0xcd,
  0x16, 0xc0, 0x07, 0xfa, 0xc7, 0xd7, 0x59, 0xc0, 0xcb, 0x41, 0xc0, 0xb1,
  0x6a, 0xc0, 0xa4, 0x88, 0xef, 0x71, 0x77, 0x10, 0xe6, 0xa6, 0xbd, 0x72,
  0x20, 0x2a, 0x89, 0x2d, 0xe2, 0x91, 0x78, 0x53, 0x71, 0x45, 0x8c, 0x13,
  0x7a, 0x53, 0xf9, 0x0b, 0x69, 0x69, 0x6e, 0x35, 0xdd, 0xeb, 0x2e, 0x07,
  0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
unsigned char devdigit_9_png[] = {
  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0x14,
  0x08, 0x06, 0x00, 0x00, 0x00, 0x56, 0x32, 0xb7, 0x2f, 0x00, 0x00, 0x01,
  0xbd, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0xc5, 0x92, 0xd9, 0x2b, 0xc4,
  0x51, 0x14, 0xc7, 0x8f, 0xd2, 0x98, 0x69, 0x8c, 0x25, 0x59, 0xb2, 0x44,
  0x79, 0x30, 0x42, 0x94, 0x22, 0x2f, 0x83, 0x79, 0x18, 0xd9, 0x9f, 0xec,
  0x4a, 0xa3, 0x3c, 0x79, 0x50, 0x3c, 0xc8, 0x2b, 0xe5, 0x41, 0x3c, 0x51,
  0x76, 0x93, 0x9d, 0x42, 0x22, 0x91, 0x22, 0xcb, 0x1f, 0x60, 0x5f, 0xca,
  0x4e, 0xb6, 0xb2, 0x97, 0x7d, 0x38, 0xce, 0xbd, 0xbf, 0x19, 0xf7, 0x97,
  0x86, 0x57, 0xbf, 0xfa, 0xbc, 0xdc, 0xef, 0xf9, 0xfc, 0xce, 0x3d, 0xb7,
  0x03, 0xf0, 0x1f, 0x5f, 0x3e, 0xb1, 0x48, 0x3c, 0x10, 0x4f, 0x32, 0x36,
  0x89, 0x2a, 0x42, 0xf3, 0x53, 0x68, 0x27, 0x30, 0x4f, 0x0f, 0xb8, 0x50,
  0x07, 0x78, 0x3f, 0x0a, 0xf8, 0x38, 0x06, 0xb8, 0xd1, 0x0a, 0x58, 0x59,
  0x00, 0xe8, 0xa8, 0x04, 0xa4, 0x7c, 0x97, 0xf0, 0xb1, 0x0a, 0x59, 0x4c,
  0x68, 0x2b, 0x05, 0xc4, 0x69, 0xdb, 0xec, 0x98, 0x00, 0xbd, 0xdd, 0xb8,
  0x38, 0x4f, 0xd8, 0x31, 0x69, 0x36, 0x53, 0x27, 0x0a, 0x56, 0x9a, 0x00,
  0x23, 0x02, 0xa5, 0xbf, 0x27, 0x47, 0x01, 0x5e, 0x0c, 0x4a, 0xe7, 0x73,
  0xb5, 0x5c, 0x62, 0x24, 0x30, 0xe9, 0x76, 0xa6, 0x46, 0x48, 0xf1, 0xe1,
  0x3c, 0x58, 0x25, 0x52, 0x88, 0xcb, 0x9c, 0x78, 0x91, 0x19, 0x22, 0x79,
  0x66, 0x62, 0xd2, 0xdb, 0xcd, 0xb0, 0x08, 0x34, 0x2a, 0x1e, 0xe8, 0x2d,
  0x57, 0xcf, 0x75, 0x73, 0x12, 0x59, 0x47, 0x19, 0xcf, 0xd6, 0xb9, 0xf4,
  0x3a, 0x21, 0x02, 0xcb, 0xd0, 0xb1, 0x16, 0x29, 0xd3, 0x45, 0x2d, 0xb2,
  0xb5, 0x16, 0x9e, 0xdd, 0x71, 0xe9, 0xb0, 0x5b, 0x04, 0xba, 0x30, 0x1e,
  0x2c, 0x13, 0xa9, 0xc4, 0x45, 0x86, 0x6c, 0xde, 0xdb, 0x11, 0x9e, 0x99,
  0x99, 0x74, 0x54, 0x5f, 0x2c, 0x82, 0xa5, 0x46, 0xc0, 0xd0, 0x00, 0x40,
  0x35, 0x75, 0x4c, 0x89, 0x06, 0x3c, 0x1f, 0x10, 0xd9, 0xfb, 0xa4, 0x90,
  0x1a, 0xdc, 0x9d, 0x01, 0x0f, 0xba, 0x6c, 0x3f, 0xf7, 0xc3, 0xa8, 0xed,
  0x4e, 0x1e, 0xc4, 0xa1, 0xa7, 0x2b, 0x60, 0x73, 0x09, 0xe0, 0x69, 0x3f,
  0x20, 0x9b, 0x71, 0xaf, 0x13, 0xb0, 0xda, 0x08, 0x98, 0x1d, 0x27, 0xa4,
  0xad, 0x76, 0x31, 0x13, 0xfb, 0xbc, 0x88, 0x16, 0xe2, 0x8c, 0xcd, 0x28,
  0x63, 0xbf, 0x28, 0x51, 0x48, 0x3d, 0xe5, 0x5c, 0xda, 0xfe, 0x6b, 0x17,
  0x43, 0x99, 0xd8, 0x57, 0x21, 0x24, 0xd6, 0x95, 0xce, 0x7a, 0xe5, 0xab,
  0x64, 0x25, 0x98, 0x48, 0x27, 0x4e, 0x42, 0xfc, 0xa5, 0xab, 0x32, 0xe1,
  0xb8, 0x17, 0x50, 0x61, 0xcf, 0xa5, 0x1c, 0xab, 0x84, 0x6c, 0x95, 0xb4,
  0x7e, 0x80, 0x4a, 0x05, 0xa0, 0x8a, 0x48, 0x8b, 0x91, 0x0a, 0x99, 0xf0,
  0x31, 0x05, 0x98, 0x14, 0xc5, 0x85, 0x13, 0xc2, 0xe1, 0x5b, 0xfa, 0x6d,
  0x59, 0x5f, 0xa8, 0x93, 0xd1, 0xc0, 0x85, 0x4f, 0x22, 0x59, 0x7e, 0x7f,
  0xbc, 0x1a, 0x02, 0x7c, 0x1a, 0x07, 0x34, 0x4f, 0x49, 0x85, 0xfb, 0x5d,
  0xd2, 0x6b, 0x06, 0xf9, 0x72, 0xe1, 0x95, 0x28, 0xfc, 0x39, 0xf4, 0x35,
  0xf1, 0x4c, 0x7c, 0xc8, 0x60, 0x85, 0x07, 0x96, 0x57, 0xd5, 0xca, 0x8b,
  0xbf, 0x00, 0xc6, 0xc4, 0x55, 0xb5, 0xfc, 0x00, 0x61, 0x42, 0x00, 0x00,
  0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};
/* }}} */

static const SplashDigit digits[] = {
    { '0', G_N_ELEMENTS(digit_0_png),   digit_0_png,   },
    { '1', G_N_ELEMENTS(digit_1_png),   digit_1_png,   },
    { '2', G_N_ELEMENTS(digit_2_png),   digit_2_png,   },
    { '3', G_N_ELEMENTS(digit_3_png),   digit_3_png,   },
    { '4', G_N_ELEMENTS(digit_4_png),   digit_4_png,   },
    { '5', G_N_ELEMENTS(digit_5_png),   digit_5_png,   },
    { '6', G_N_ELEMENTS(digit_6_png),   digit_6_png,   },
    { '7', G_N_ELEMENTS(digit_7_png),   digit_7_png,   },
    { '8', G_N_ELEMENTS(digit_8_png),   digit_8_png,   },
    { '9', G_N_ELEMENTS(digit_9_png),   digit_9_png,   },
    { '.', G_N_ELEMENTS(digit_dot_png), digit_dot_png, },
};

static const SplashDigit devdigits[] = {
    { '0', G_N_ELEMENTS(devdigit_0_png), devdigit_0_png, },
    { '1', G_N_ELEMENTS(devdigit_1_png), devdigit_1_png, },
    { '2', G_N_ELEMENTS(devdigit_2_png), devdigit_2_png, },
    { '3', G_N_ELEMENTS(devdigit_3_png), devdigit_3_png, },
    { '4', G_N_ELEMENTS(devdigit_4_png), devdigit_4_png, },
    { '5', G_N_ELEMENTS(devdigit_5_png), devdigit_5_png, },
    { '6', G_N_ELEMENTS(devdigit_6_png), devdigit_6_png, },
    { '7', G_N_ELEMENTS(devdigit_7_png), devdigit_7_png, },
    { '8', G_N_ELEMENTS(devdigit_8_png), devdigit_8_png, },
    { '9', G_N_ELEMENTS(devdigit_9_png), devdigit_9_png, },
};

static gint
composite_pixbuf(GdkPixbuf *base,
                 const guchar *pngdata, gsize pnglen, gint xpos, gint ypos,
                 GError **error)
{
    GdkPixbufLoader *loader;
    GdkPixbuf *text;

    loader = gdk_pixbuf_loader_new_with_type("png", error);
    /* We have already successfully loaded base PNG */
    g_assert(loader);

    if (!gdk_pixbuf_loader_write(loader, pngdata, pnglen, error)) {
        g_critical("Cannot load in-line image as PNG.");
        return G_MAXINT;
    }
    if (!gdk_pixbuf_loader_close(loader, error)) {
        g_critical("Cannot load in-line image as PNG.");
        return G_MAXINT;
    }

    text = gdk_pixbuf_loader_get_pixbuf(loader);
    g_assert(text);

    gdk_pixbuf_composite(text, base, xpos, ypos,
                         gdk_pixbuf_get_width(text),
                         gdk_pixbuf_get_height(text),
                         xpos, ypos, 1.0, 1.0, GDK_INTERP_NEAREST, 255);
    xpos += gdk_pixbuf_get_width(text);
    g_object_unref(loader);

    return xpos;
}

static GdkPixbuf*
compose_splash(const gchar *version, const gchar *extraversion)
{
    gint xpos = 240;
    gint ypos = 36;
    GdkPixbuf *base;
    GError *err = NULL;
    guint i;
    gchar *filename;

    filename = gwy_find_self_path("data", "pixmaps", "splash.png", NULL);

    base = gdk_pixbuf_new_from_file(filename, &err);
    if (!base) {
        g_warning("Cannot load base splash image: %s", err->message);
        g_clear_error(&err);
        g_free(filename);
        return NULL;
    }
    g_free(filename);

    while (*version) {
        for (i = 0; i < G_N_ELEMENTS(digits); i++) {
            if (*version == digits[i].c)
                break;
        }
        if (i == G_N_ELEMENTS(digits)) {
            g_warning("Cannot find image for %c", *version);
            version++;
            continue;
        }

        xpos = composite_pixbuf(base, digits[i].data, digits[i].len,
                                xpos, ypos, &err);
        if (xpos == G_MAXINT)
            return base;
        version++;
    }

    if (extraversion) {
        xpos = 7;
        ypos = 214;
        xpos = composite_pixbuf(base, development_snapshot_png,
                                G_N_ELEMENTS(development_snapshot_png),
                                xpos, ypos, &err);
        if (xpos == G_MAXINT)
            return base;

        xpos += 4;
        while (*extraversion) {
            for (i = 0; i < G_N_ELEMENTS(devdigits); i++) {
                if (*extraversion == devdigits[i].c)
                    break;
            }
            if (i == G_N_ELEMENTS(devdigits)) {
                g_warning("Cannot find image for %c", *extraversion);
                extraversion++;
                continue;
            }

            xpos = composite_pixbuf(base, devdigits[i].data, devdigits[i].len,
                                    xpos, ypos, &err);
            if (xpos == G_MAXINT)
                return base;
            extraversion++;
        }
    }

    return base;
}

/**
 * gwy_app_splash_start:
 * @visible: If %FALSE, splash screen is not actually shown, all functions just
 *           silently return.
 *
 * Starts splash screen.
 **/
void
gwy_app_splash_start(gboolean visible)
{
    GtkWidget *image, *vbox, *frame, *lab;
    GdkPixbuf *pixbuf;
    char *p, *version;
    const gchar *extraversion;

    gwy_debug("");
    g_return_if_fail(!in_splash);
    in_splash = TRUE;

    if (!visible)
        return;

    window = gtk_window_new(GTK_WINDOW_POPUP);
    p = g_strconcat(_("Starting "), g_get_application_name(), NULL);
    gtk_window_set_title(GTK_WINDOW(window), p);
    gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
    gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
    gtk_window_set_decorated(GTK_WINDOW(window), FALSE);
    gtk_window_set_type_hint(GTK_WINDOW(window),
                             GDK_WINDOW_TYPE_HINT_SPLASHSCREEN);

    g_signal_connect_swapped(window, "delete-event",
                             G_CALLBACK(exit), GINT_TO_POINTER(0));
    /* we don't want the splash screen to send the startup notification */
    gtk_window_set_auto_startup_notification(FALSE);
    g_signal_connect(window, "map", G_CALLBACK(splash_map), NULL);

    frame = gtk_frame_new(NULL);
    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_OUT);
    gtk_container_add(GTK_CONTAINER(window), frame);

    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
    gtk_container_add(GTK_CONTAINER(frame), vbox);
    gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);

    version = g_strdup_printf("%d.%d", GWY_VERSION_MAJOR, GWY_VERSION_MINOR);
    extraversion = GWY_VERSION_STRING;
    if (extraversion)
        extraversion = strchr(extraversion, '.');
    if (extraversion)
        extraversion = strchr(extraversion+1, '.');
    if (extraversion)
        extraversion++;
    pixbuf = compose_splash(version, extraversion);
    g_free(version);
    if (pixbuf) {
        image = gtk_image_new_from_pixbuf(pixbuf);
        g_object_unref(pixbuf);
    }
    else
        image = gtk_image_new_from_icon_name("missing-image", GTK_ICON_SIZE_DIALOG);
    gtk_box_pack_start(GTK_BOX(vbox), image, FALSE, FALSE, 0);

    label = gtk_label_new(p);
    gtk_label_set_xalign(GTK_LABEL(label), 0.0);
    gwy_set_widget_padding(label, 6, 6, 4, 4);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
    g_free(p);

    lab = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start(GTK_BOX(vbox), lab, FALSE, FALSE, 0);

    p = g_strconcat("<small>", PACKAGE_NAME,
                    _(" is free software released under GNU GPL."), "</small>",
                    NULL);
    lab = gtk_label_new(NULL);
    gtk_label_set_markup(GTK_LABEL(lab), p);
    gtk_label_set_xalign(GTK_LABEL(lab), 0.0);
    gwy_set_widget_padding(lab, 5, 5, 3, 3);
    gtk_box_pack_start(GTK_BOX(vbox), lab, FALSE, FALSE, 0);
    g_free(p);

    gtk_widget_show_all(window);

    while (gtk_events_pending())
        gtk_main_iteration();
}

void
gwy_app_splash_finish(void)
{
    g_return_if_fail(in_splash);
    if (!window)
        return;

    gtk_widget_destroy(window);

    window = NULL;
    label = NULL;

    while (gtk_events_pending())
        gtk_main_iteration();
}

void
gwy_app_splash_set_message(const gchar *message)
{
    g_return_if_fail(in_splash);
    if (!window)
        return;

    while (gtk_events_pending())
        gtk_main_iteration();

    gtk_label_set_markup(GTK_LABEL(label), message);

    while (gtk_events_pending())
        gtk_main_iteration();
}

static void
splash_map(void)
{
    /* Reenable startup notification after the splash has been shown
     * so that the next window that is mapped sends the notification. */
    gtk_window_set_auto_startup_notification(TRUE);
}

/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
